<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Retirio_Elementor_Blog_Grid_2 extends Widget_Base {

	
	public function get_name() {
		return 'retirio_elementor_blog_grid_2';
	}

	
	public function get_title() {
		return esc_html__( 'Blog Grid 2', 'retirio' );
	}

	
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	
	public function get_categories() {
		return [ 'retirio' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {
		
		$args = array(
			  'orderby' => 'name',
			  'order' => 'ASC'
			  );

			$categories=get_categories($args);
			$cate_array = array();
			$arrayCateAll = array( 'all' => esc_html__( 'All categories', 'retirio' ) );
			if ($categories) {
				foreach ( $categories as $cate ) {
					$cate_array[$cate->cat_name] = $cate->slug;
				}
			} else {
				$cate_array[ esc_html__( 'No content Category found', 'retirio' ) ] = 0;
			}

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'retirio' ),
			]
		);	
			
			
			// Add Class control
			$this->add_control(
				'category',
				[
					'label' => esc_html__( 'Category', 'retirio' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'all',
					'options' => array_merge($arrayCateAll,$cate_array),
				]
			);

			$this->add_control(
				'total_count',
				[
					'label' => esc_html__( 'Post Total', 'retirio' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 3,
				]
			);

			$this->add_control(
				'number_column',
				[
					'label' => esc_html__( 'Columns', 'retirio' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'columns3',
					'options' => [
						'columns2' => esc_html__( '2 Columns', 'retirio' ),
						'columns3' => esc_html__( '3 Columns', 'retirio' ),
						'columns4' => esc_html__( '4 Columns', 'retirio' ),
					]
				]
			);


			$this->add_control(
				'order_by',
				[
					'label' => esc_html__('Order', 'retirio'),
					'type' => Controls_Manager::SELECT,
					'default' => 'desc',
					'options' => [
						'asc' => esc_html__('Ascending', 'retirio'),
						'desc' => esc_html__('Descending', 'retirio'),
					]
				]
			);

			$this->add_control(
				'show_date',
				[
					'label' => esc_html__( 'Show Date', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'retirio' ),
					'label_off' => esc_html__( 'Hide', 'retirio' ),
					'return_value' => 'yes',
					'default' => 'yes',
				]
			);

			$this->add_control(
				'show_comment',
				[
					'label' => esc_html__( 'Show comments', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'retirio' ),
					'label_off' => esc_html__( 'Hide', 'retirio' ),
					'return_value' => 'yes',
					'default' => 'yes',
				]
			);

			$this->add_responsive_control(
				'align_item',
				[
					'label' 	=> esc_html__( 'Alignment', 'retirio' ),
					'type' 		=> \Elementor\Controls_Manager::CHOOSE,
					'options' 	=> [
						'left' => [
							'title' => esc_html__( 'Left', 'retirio' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'retirio' ),
							'icon' 	=> 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'retirio' ),
							'icon' 	=> 'eicon-text-align-right',
						],
					],
				
					'toggle' 	=> true,
					'selectors' => [
						'{{WRAPPER}} .ova-blog2 .item .info-blog' => 'text-align: {{VALUE}}',

					],
				]
			);

		$this->end_controls_section();

 //*************************************************//
// ****************** TAB STYLES ******************//
		
		//SECTION TAB STYLE CONTENT
		$this->start_controls_section(
			'section_Content',
			[
				'label' => esc_html__( 'Content', 'retirio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_responsive_control(
				'content_padding',
				[
					'label' => esc_html__( 'Padding', 'retirio' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-blog2 .item .info-blog' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		//END SECTION TAB STYLE CONTENT
		
		//SECTION TAB STYLE IMAGE
		$this->start_controls_section(
			'section_Image',
			[
				'label' => esc_html__( 'Image', 'retirio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_responsive_control(
				'Image_margin',
				[
					'label' => esc_html__( 'Margin', 'retirio' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-blog2 .item .media' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			// min height
			$this->add_control(
				'image_min_height',
				[
					'label' 		=> esc_html__( 'Min height (px)', 'retirio' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px' ],
					'range' => [
						'px' => [
							'min' 	=> 50,
							'max' 	=> 500,
							'step' 	=> 1,
						]
					],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-blog2 .media img' => 'min-height: {{SIZE}}{{UNIT}};',

					],
				]
			);

			// hover rolate


		$this->end_controls_section();
		//END SECTION TAB STYLE IMAGE
		
		
		//SECTION TAB STYLE TITLE
		$this->start_controls_section(
			'section_title',
			[
				'label' => esc_html__( 'Title', 'retirio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'title_typography',
					'selector' => '{{WRAPPER}} .ova-blog2 .post-title a',
				]
			);

			$this->add_control(
				'color_title',
				[
					'label' => esc_html__( 'Color Title', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-blog2 .post-title a' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'color_title_hover',
				[
					'label' => esc_html__( 'Color Title Hover', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-blog2 .post-title a:hover' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_title',
				[
					'label' => esc_html__( 'Margin', 'retirio' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-blog2 .post-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		//END SECTION TAB STYLE TITLE
		
		//SECTION TAB STYLE META
		$this->start_controls_section(
			'section_meta',
			[
				'label' => esc_html__( 'Meta', 'retirio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_control(
				'meta_author_Comment',
				[
					'label' => esc_html__( 'Comment', 'retirio' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);
			//.ova-blog .item .post-author a, .ova-blog .item .comment a
				$this->add_group_control(
					Group_Control_Typography::get_type(),
					[
						'name' => 'meta_typography',
						'selector' => '{{WRAPPER}} .ova-blog2 .item .comment a,.ova-blog2 .item .comment i',
						
					]
				);

				$this->add_control(
					'meta_color',
					[
						'label' => esc_html__( 'Color', 'retirio' ),
						'type' => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-blog2 .item .comment a' => 'color : {{VALUE}};',
						],
					]
				);
				$this->add_control(
					'meta_color_icon',
					[
						'label' => esc_html__( 'Color icon', 'retirio' ),
						'type' => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-blog2 .item .comment i' => 'color : {{VALUE}};',
						],
					]
				);

				$this->add_control(
					'meta_color_hover',
					[
						'label' => esc_html__( 'Color hover', 'retirio' ),
						'type' => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-blog2 .item .comment a:hover' => 'color : {{VALUE}};',
						],
					]
				);

				$this->add_responsive_control(
					'margin_comment',
					[
						'label' => esc_html__( 'Margin comment', 'retirio' ),
						'type' => Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors' => [
							'{{WRAPPER}} .ova-blog2 .item .comment' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
				//code
			$this->add_control(
				'meta_date',
				[
					'label' => esc_html__( 'Date', 'retirio' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);
				//code
				$this->add_group_control(
					Group_Control_Typography::get_type(),
					[
						'name' => 'date_typography',
						'selector' => '{{WRAPPER}} .ova-blog2 .item .post-date span',
						
					]
				);

				$this->add_control(
					'date_color',
					[
						'label' => esc_html__( 'Color', 'retirio' ),
						'type' => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-blog2 .item .post-date span' => 'color : {{VALUE}};',	
						],
					]
				);

				$this->add_control(
					'meta_date_color_background',
					[
						'label' => esc_html__( 'Background', 'retirio' ),
						'type' => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-blog2 .item .post-date' 	 => 'background-color : {{VALUE}};',
							
						],
					]
				);

				$this->add_responsive_control(
					'mete_date_padding',
					[
						'label' => esc_html__( 'Padding author', 'retirio' ),
						'type' => Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors' => [
							'{{WRAPPER}} .ova-blog2 .item .post-date' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
		$this->end_controls_section();
		//END SECTION TAB STYLE META
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

			$category      = $settings['category'];
			$total_count   = $settings['total_count'];
			$order 		   = $settings['order_by'];
			$number_column = $settings['number_column'];

			
			$show_date 	   = $settings['show_date'];
			$show_comment 	 = $settings['show_comment'];
		
			$args = [];
			if ($category == 'all') {
				$args=[
					'post_type' 	 => 'post',
					'posts_per_page' => $total_count,
					'order' 		 => $order,
				];
			} else {
				$args = [
					'post_type' 	 => 'post', 
					'category_name'  =>$category,
					'posts_per_page' => $total_count,
					'order' 		 => $order,
					'fields'		 => 'ids'
				];
			}

			$blog = new \WP_Query($args);
		?>
		<ul class="ova-blog2 <?php echo esc_attr( $number_column ); ?>">
			<?php
				if($blog->have_posts()) : while($blog->have_posts()) : $blog->the_post();
			?>
				<li class="item">

					

					    <div class="media">
						    <?php 
				        		$thumbnail = wp_get_attachment_image_url(get_post_thumbnail_id() , 'retirio_project_thumbnail ' );
				        		$url_defautl = \Elementor\Utils::get_placeholder_image_src();

				        		if( has_post_thumbnail()){
				        			$thumbnail_id = $thumbnail;
				        		} else{
				        			$thumbnail_id = $url_defautl;
				        		}

				        	?>
							<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>">
								<img src="<?php echo esc_url( $thumbnail_id ); ?>" alt=" <?php the_title(); ?>">
							</a>
				        	
							<?php if( $show_date == 'yes' ){ ?>
								<div class="post-date">
									<span class="right-j"><?php the_time('j' );?></span>
									<span class="right-f"><?php the_time('F' );?></span>
								</div>
							<?php } ?> 

				        </div>

			        
					<div class="info-blog">	
						<div class="post-meta">
						
							<?php if($show_comment == 'yes'): ?>

								<div class="comment">
										<i aria-hidden="true" class="fas fa-comments"></i>
										<?php
										comments_popup_link(
											esc_html__(' 0 Comment', 'retirio'), 
											esc_html__(' 1 Comment', 'retirio'), 
											' % Comment',
											'',
											esc_html__( 'Comment off', 'retirio' ) )
										; ?>              
								</div>

							<?php endif; ?>
						</div>
						<h2 class="post-title">
							<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>">
								<?php the_title(); ?>
							</a>
						</h2>
						
					</div>
				</li>	
					
			<?php
				endwhile; endif; wp_reset_postdata();
			?>
		</ul>
		 	
		<?php
	}

	
}
$widgets_manager->register( new Retirio_Elementor_Blog_Grid_2() );