<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Retirio_Elementor_Image extends Widget_Base {

	
	public function get_name() {
		return 'retirio_elementor_image';
	}

	
	public function get_title() {
		return esc_html__( 'Ova Image', 'retirio' );
	}

	
	public function get_icon() {
		return 'eicon-image';
	}

	
	public function get_categories() {
		return [ 'retirio' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'retirio' ),
			]
		);	
			$this->add_control(
				'template',
				[
					'label' => esc_html__( 'Template', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'template_1',
					'options' => [
						'template_1'  => esc_html__( 'Template 1', 'retirio' ),
						'template_2'  => esc_html__( 'Template 2', 'retirio' ),
					],
				]
			);
			
			$this->add_control(
				'template_type',
				[
					'label' => esc_html__( 'Type', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'type1',
					'options' => [
						'type1'  => esc_html__( 'Type 1', 'retirio' ),
						'type2'  => esc_html__( 'Type 2', 'retirio' ),
					],
					'condition' => [
						'template' => ['template_1'],
					],
				]
			);

			$this->add_control(
				'show_border',
				[
					'label' => esc_html__( 'Show Border', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'retirio' ),
					'label_off' => esc_html__( 'Hide', 'retirio' ),
					'return_value' => 'yes',
					'default' => 'no',
					'condition' => [
						'template' => ['template_1'],
						'template_type' =>  'type2',
					],
				]
			);

			$this->add_control(
				'image',
				[
					'label' 	=> esc_html__( 'Image', 'retirio' ),
					'type' 		=> Controls_Manager::MEDIA,
					'dynamic' 	=> [
						'active' 	=> true,
					],
					'default' 	=> [
						'url' 	=> Utils::get_placeholder_image_src(),
					],
				]
			);

			$this->add_responsive_control(
				'image_width_template1_type2',
				[
					'label' => esc_html__( 'Width', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 170,
							'max' => 550,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-img.template1.type2.border' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'template' => ['template_1'],
						'template_type' => 'type2',
						'show_border' =>  'yes'
					],
				]
			);

			$this->add_responsive_control(
				'image_height_template1_type2',
				[
					'label' => esc_html__( 'Border Size', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 5,
							'max' => 20,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-img img' => 'height:calc(100% - {{SIZE}}{{UNIT}});',
					],
					'condition' => [
						'template' => ['template_1'],
						'template_type' => 'type2',
						'show_border' =>  'yes'
					],
				]
			);

			$this->add_control(
				'border_color',
				[
					'label' => esc_html__( 'Border color', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-img.template1.type2.border' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'template' => ['template_1'],
						'template_type' => 'type2',
						'show_border' =>  'yes'
					],
				]
			);

			$this->add_responsive_control(
				'image_width_template1_type1',
				[
					'label' => esc_html__( 'Width', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 170,
							'max' => 550,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-img.template1.type1 img' => 'width: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'template' => ['template_1'],
						'template_type' => 'type1',
					],
				]
			);
			$this->add_responsive_control(
				'image_width_template1_type2_no_border',
				[
					'label' => esc_html__( 'Width', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 170,
							'max' => 550,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-img.template1.type2' => 'max-width: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'template' => ['template_1'],
						'template_type' => 'type2',
						'show_border!' =>  'yes'
					],
				]
			);

			$this->add_responsive_control(
				'image_width',
				[
					'label' => esc_html__( 'Width', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 170,
							'max' => 550,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-img img' => 'width: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'template' => 'template_2',
					],
				]
			);

			$this->add_responsive_control(
				'image_height',
				[
					'label' => esc_html__( 'Height', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 520,
							'max' => 1000,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-img img' => 'height: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'template' => 'template_2',
					],
				]
			);

			$this->add_responsive_control(
	            'image_display',
	            [
	                'label' 	=> esc_html__( 'Display', 'retirio' ),
	                'type' 		=> \Elementor\Controls_Manager::CHOOSE,
	                'options' 	=> [
	                    'flex' => [
	                        'title' => esc_html__( 'Flex', 'retirio' ),
	                        'icon' 	=> 'eicon-h-align-left',
	                    ],
	                    'inline-flex' => [
	                        'title' => esc_html__( 'Inline-flex', 'retirio' ),
	                        'icon' 	=> 'eicon-h-align-center',
	                    ],
	                ],
	                'selectors' => [
	                    '{{WRAPPER}} .ova-img' => 'display: {{VALUE}}',
	                ],
	                'template' => 'template_2',
	            ]
	        );

			$this->add_control(
				'show_line_right_heading',
				[
					'label' => esc_html__( 'Line Right', 'retirio' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'template' => 'template_2',
					],
				]
			);

			$this->add_control(
				'show_line_right',
				[
					'label' => esc_html__( 'Show Line Right', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'retirio' ),
					'label_off' => esc_html__( 'Hide', 'retirio' ),
					'return_value' => 'yes',
					'default' => 'no',
					'condition' => [
						'template' =>  'template_2',
					],
				]
			);

			$this->add_control(
				'line_color',
				[
					'label' => esc_html__( 'Color', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-img .line' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'show_line_right' => 'yes',
						'template' => 'template_2',
					],
				]
			);

			$this->add_responsive_control(
				'line_width',
				[
					'label' => esc_html__( 'Width (px)', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 1,
							'max' => 50,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-img .line' => 'width: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'show_line_right' => 'yes',
						'template' => 'template_2',

					],
				]
			);

			$this->add_control(
				'show_line_left_heading',
				[
					'label' => esc_html__( 'Line Left', 'retirio' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'template' => 'template_2',
					],
				]
			);

			$this->add_control(
				'show_line_left',
				[
					'label' => esc_html__( 'Show Line Left', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'retirio' ),
					'label_off' => esc_html__( 'Hide', 'retirio' ),
					'return_value' => 'yes',
					'default' => 'no',
					'condition' => [
						'template' =>  'template_2',
					],
				]
			);

			$this->add_control(
				'line_color_left',
				[
					'label' => esc_html__( 'Color', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-img .line.line-left' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'show_line_left' => 'yes',
						'template' => 'template_2',
					],
				]
			);

			$this->add_responsive_control(
				'line_width_left',
				[
					'label' => esc_html__( 'Width (px)', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 1,
							'max' => 50,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-img .line.line-left' => 'width: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'show_line_left' => 'yes',
						'template' => 'template_2',
					],
				]
			);

			$this->add_control(
				'show_text_left_heading',
				[
					'label'     => esc_html__( 'Text left', 'retirio' ),
					'type'      => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'template' =>  'template_2',
					],
				]
			);
			
			$this->add_control(
				'show_text_left',
				[
					'label'     => esc_html__( 'Show Text Left', 'retirio' ),
					'type'      => \Elementor\Controls_Manager::SWITCHER,
					'label_on'  => esc_html__( 'Show', 'retirio' ),
					'label_off' => esc_html__( 'Hide', 'retirio' ),
					'return_value' => 'yes',
					'default'      => 'yes',
					'condition'    => [
						'template'   =>  'template_2',
					],
				]
			);

			$this->add_control(
				'text_left',
				[
					'label'   => esc_html__( 'Text content', 'retirio' ),
					'type'    => \Elementor\Controls_Manager::TEXT,
					'description' => esc_html__( 'Text vertical align left', 'retirio' ),
					'default' => 'ARCHITECT',
					'condition' => [
						'show_text_left' => 'yes',
						'template'   =>  'template_2',
					]
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'text_left_typography',
					'selector' => '{{WRAPPER}} .ova-img .line-left.text h2',
					'condition' => [
						'show_text_left' => 'yes',
						'template'   =>  'template_2',
					]
				]
			);
			
			$this->add_control(
				'text_left_color',
				[
					'label' => esc_html__( 'Color', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-img .line-left.text h2' => 'color : {{VALUE}};',
					],
					'condition' => [
						'show_text_left' => 'yes',
						'template'   =>  'template_2',
					]
				]
			);

			$this->add_responsive_control(
				'text_left_margin',
				[
					'label' => esc_html__( 'Margin Left', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', 'em', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-img .line-left.text h2' => 'margin-top: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'show_text_left' => 'yes',
						'template'   =>  'template_2',
					]
				]
			);

		$this->end_controls_section();

		
	}

	// Render Template Here
	protected function render() {

		$settings  = $this->get_settings();


		// Get url image
		$url 	   = $settings['image']['url'];
		$alt 	   = isset( $settings['image']['alt'] ) ? $settings['image']['alt'] : '';

		//show line
		
		//template 1 + type 1
		
		$template_type 	 = $settings['template_type'];

		$show_border 	 = $settings['show_border'] == 'yes' ? 'border' : '';

		$show_line_right = $settings['show_line_right'];
		$show_line_left  = $settings['show_line_left']; 

		$show_text_left  = $settings['show_text_left'];
		$text_left       = $settings['text_left'];	
?>
		 
		<?php if($settings['template'] == 'template_1'): ?>

				<div class="ova-img template1 <?php echo esc_attr($template_type);?> <?php echo esc_attr( $show_border ); ?> ">

					<img src="<?php echo esc_url( $url ); ?>" alt="<?php echo esc_attr( $alt ); ?>">
			</div>

		<?php endif; ?>

		<?php if($settings['template'] == 'template_2'): ?>

		   	<div class="ova-img template2">
		   		<img src="<?php echo esc_url( $url ); ?>" alt="<?php echo esc_attr( $alt ); ?>">
				
				<?php if($show_line_right == 'yes'): ?>
					<div class="line line-right"></div>
				<?php endif; ?>

				<?php if($show_line_left == 'yes'): ?>
					<div class="line line-left"></div>
				<?php endif; ?>

				<?php if($show_text_left == 'yes' && $text_left != ''): ?>
					<div class="line-left text">
						<h2><?php echo esc_html($text_left); ?></h2>
					</div>
				<?php endif; ?>
			</div>

		<?php endif; 
	}
	
}
$widgets_manager->register( new Retirio_Elementor_Image() );