<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Retirio_Elementor_Ova_Icon_Box_2 extends Widget_Base {

	
	public function get_name() {
		return 'retirio_elementor_ova_icon_box_2';
	}

	
	public function get_title() {
		return esc_html__( 'Ova Icon Box 2', 'retirio' );
	}

	
	public function get_icon() {
		return 'eicon-icon-box';
	}

	
	public function get_categories() {
		return [ 'retirio' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'retirio' ),
			]
		);	
				
			// Add Class control
			$this->add_control(
				'icon',
				[
					'label' => esc_html__( 'Class Icon', 'retirio' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' 	=> [
						'value' 	=> 'flaticon flaticon-concept',
						'library' 	=> 'flaticon',
					],
				]
			);

			$this->add_control(
				'text',
				[
					'label' => esc_html__( 'Text', 'retirio' ),
					'type' => Controls_Manager::TEXTAREA,
				]
			);

			$this->add_control(
				'numerical_order',
				[
					'label' => esc_html__( 'Numerical order', 'retirio' ),
					'type' => Controls_Manager::TEXT,
					'default' => '01',
				]
			);

			$this->add_control(
				'text_position',
				[
					'label' 	=> esc_html__( 'Alignment', 'retirio' ),
					'type' 		=> \Elementor\Controls_Manager::CHOOSE,
					'default'	=> 'bottom-left',
					'options' 	=> [
						'top-left' => [
							'title' => esc_html__( 'Top Left', 'retirio' ),
							'icon' 	=> 'eicon-v-align-top',
						],
						
						'bottom-left' => [
							'title' => esc_html__( 'Bottom Left', 'retirio' ),
							'icon' 	=> 'eicon-v-align-bottom',
						],
					],
					'toggle' 	=> true,
				]
			);


		$this->end_controls_section();

		////////////////////===TAB STYLES===////////////////////
		
		//box
		$this->start_controls_section(
			'style_section_icon_box',
			[
				'label' => esc_html__( 'Box', 'retirio' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'icon_background_box',
				[
					'label' => esc_html__( 'Background box', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-box .ova-icon-box-2' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon_box_margin',
				[
					'label' => esc_html__( 'Margin', 'retirio' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-box .ova-icon-box-2 .icon-box' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border',
					'label' => esc_html__( 'Border', 'retirio' ),
					'selector' => '{{WRAPPER}} .ova-box .ova-icon-box-2 ',
				]
			);
			
			$this->add_control(
				'icon_background',
				[
					'label' => esc_html__( 'Background icon', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-box .ova-icon-box-2 .icon-box' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'icon_box_w',
				[
					'label' => esc_html__( 'Width', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 10,
							'max' => 300,
							'step' => 1,
						]
					],
					'default' => [
						'unit' => 'px',
						'size' => 142,
					],
					'selectors' => [
						'{{WRAPPER}} .ova-box .ova-icon-box-2 .icon-box' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		//end-box

		//text
		$this->start_controls_section(
			'style_section_content',
			[
				'label' => esc_html__( 'Text', 'retirio' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'color_text',
				[
					'label' => esc_html__( 'Color', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-box .text' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'text_typography',
					'selector' => '{{WRAPPER}} .ova-box .text',
				]
			);

			$this->add_responsive_control(
				'text_padding',
				[
					'label' => esc_html__( 'Padding', 'retirio' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-box .text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'top',
				[
					'label' => esc_html__( 'Top', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => -200,
							'max' => 10,
							'step' => -1,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => -74,
					],
					'selectors' => [
						'{{WRAPPER}} .ova-box .text' => 'top: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'text_position' => 'top-left',
					],
				]
			);

			$this->add_responsive_control(
				'bottom',
				[
					'label' => esc_html__( 'Bottom', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => -200,
							'max' => 200,
							'step' => -1,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => -74,
					],
					'selectors' => [
						'{{WRAPPER}} .ova-box .text' => 'bottom: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'text_position' => 'bottom-left',
					],
				]
			);

			$this->add_responsive_control(
				'left',
				[
					'label' => esc_html__( 'Left', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => -200,
							'max' => 200,
							'step' => -1,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => -20,
					],
					'selectors' => [
						'{{WRAPPER}} .ova-box .text' => 'left: {{SIZE}}{{UNIT}};',
						],
						
				]
			);

		$this->end_controls_section();
		//end-text
		
		//icon
		$this->start_controls_section(
			'style_section_icon',
			[
				'label' => esc_html__( 'Icon', 'retirio' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'icon_fontsize',
				[
					'label' => esc_html__( 'Font Size', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 1,
							'max' => 300,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-box .icon i' => 'font-size: {{SIZE}}{{UNIT}};',
						
					],
				]
			);

			$this->add_control(
				'icon_color',
				[
					'label' => esc_html__( 'color', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-box .icon i' => 'color : {{VALUE}};',
					],
				]
			);

		$this->end_controls_section();
		//end-icon
		

		//number order numerical order
		$this->start_controls_section(
			'style_numerical order',
			[
				'label' => esc_html__( 'Numerical Order', 'retirio' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'order_text_typography',
					'selector' => '{{WRAPPER}} .ova-box .number_section',
				]
			);

			$this->add_control(
				'order_color_text',
				[
					'label' => esc_html__( 'Color', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-box .number_section' => 'color : {{VALUE}};',
					],
					 
				]
			);

			$this->add_responsive_control(
				'top_order',
				[
					'label' => esc_html__( 'Top', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => -50,
							'max' => 20,
							'step' => -1,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => -5,
					],
					'selectors' => [
						'{{WRAPPER}} .ova-box .number_section.bottom-left' => 'top: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'text_position' => 'bottom-left',
					],
				]
			);

			$this->add_responsive_control(
				'right_order',
				[
					'label' => esc_html__( 'Right', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => -200,
							'max' => 10,
							'step' => -1,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => -90,
					],
					'selectors' => [
						'{{WRAPPER}} .ova-box .number_section.bottom-left' => 'right: {{SIZE}}{{UNIT}};',
						],
					'condition' => [
						'text_position' => 'bottom-left',
					],
						
				]
			);

			$this->add_responsive_control(
				'bottom_order',
				[
					'label' => esc_html__( 'Bottom', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => -50,
							'max' => 20,
							'step' => -1,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => 5,
					],
					'selectors' => [
						'{{WRAPPER}} .ova-box .number_section.top-left' => 'bottom: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'text_position' => 'top-left',
					],
				]
			);

			$this->add_responsive_control(
				'right_order_t',
				[
					'label' => esc_html__( 'Right', 'retirio' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => -200,
							'max' => 10,
							'step' => -1,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => -90,
					],
					'selectors' => [
						'{{WRAPPER}} .ova-box .number_section.top-left' => 'right: {{SIZE}}{{UNIT}};',
						],
					'condition' => [
						'text_position' => 'top-left',
					],
						
				]
			);

		$this->end_controls_section();
		//end number
		////////////////////===END TAB STYLES===////////////////////
	}

	// Render Template Here
	protected function render() {

		$settings 		= $this->get_settings();
		$icon 			= $settings['icon'] ? $settings['icon'] : '';

		$text 			= $settings['text'];
		$number_order   = $settings['numerical_order'];

		$text_position  = $settings['text_position'];

		?>

			<div class="ova-box">

				<div class="ova-icon-box-2  <?php echo esc_attr( $text_position ); ?>">
					<div class="icon-box" >	
					</div>
				</div>

				<div class="icon">
					<?php 
					    \Elementor\Icons_Manager::render_icon( $icon, [ 'aria-hidden' => 'true' ] );
					?>
				</div>

				<div class="text <?php echo esc_attr( $text_position ); ?>">
					<span><?php echo esc_html( $text ); ?></span>
				</div>

				<div class="number_section <?php echo esc_attr( $text_position ); ?>">
					<span><?php echo esc_html( $number_order ); ?></span>

				</div>

			</div>
			
		<?php
	}
}

$widgets_manager->register( new Retirio_Elementor_Ova_Icon_Box_2() );