<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Retirio_Elementor_Ova_Icon_Box extends Widget_Base {

	
	public function get_name() {
		return 'retirio_elementor_ova_icon_box';
	}

	
	public function get_title() {
		return esc_html__( 'Ova Icon Box', 'retirio' );
	}

	
	public function get_icon() {
		return 'eicon-icon-box';
	}

	
	public function get_categories() {
		return [ 'retirio' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'retirio' ),
			]
		);	
			// Add Class control
			$this->add_control(
				'template',
				[
					'label' => esc_html__( 'Template', 'retirio' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'template2',
					'options' => [
						'template1' => esc_html__('Template 1', 'retirio'),
						'template2' => esc_html__('Template 2', 'retirio'),
					]
				]
			);
			
			$this->add_control(
				'icon_box_active',
				[
					'label'   => esc_html__( 'Active Mode', 'retirio' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'no',
					'options' => [
						'yes' => esc_html__( 'Yes', 'retirio' ),
						'no'  => esc_html__( 'No', 'retirio' ),
					],
					'condition' => [
						'template' => 'template2'
					]
				]
			);

			$this->add_control(
				'icon',
				[
					'label' => esc_html__( 'Icon', 'retirio' ),
					'type' => Controls_Manager::ICONS,
					'default' 	=> [
						'value' 	=> 'flaticon flaticon-buildings',
						'library' 	=> 'flaticon',
					],
				]
			);

			$this->add_control(
				'text_number',
				[
					'label' => esc_html__( 'Text Number', 'retirio' ),
					'type' => Controls_Manager::TEXT,
					'default' => '01',
					'condition' => [
						'template' => 'template1'
					]
				]
			);
				
			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'retirio' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__( 'Kitchens', 'retirio' ),
				]
			);

			$this->add_control(
				'link',
				[
					'label' => esc_html__( 'Link Title', 'retirio' ),
					'type' => Controls_Manager::URL,
					'dynamic' => [
						'active' => true,
					],
					'placeholder' => esc_html__( 'https://your-link.com', 'retirio' ),
					'show_label' => true,
				]
			);

			$this->add_control(
				'description',
				[
					'label' 	=> esc_html__( 'Description', 'retirio' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__( 'Nunc eleifend eget nunc eget consequat. Etiam sed varius est. Proin et lacus odio.', 'retirio' ),
				]
			);

			$this->add_responsive_control(
				'align',
				[
					'label' 	=> esc_html__( 'Alignment', 'retirio' ),
					'type' 		=> Controls_Manager::CHOOSE,
					'options' 	=> [
						'left' 	=> [
							'title' => esc_html__( 'Left', 'retirio' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'retirio' ),
							'icon' 	=> 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'retirio' ),
							'icon' 	=> 'eicon-text-align-right',
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box' => 'text-align: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'background_image_box',
				[
					'label'   => esc_html__( 'Box Background Image', 'retirio' ),
					'type'    => \Elementor\Controls_Manager::MEDIA,
					'condition' => [
						'template' => [
							'template2',
						]
					],
					'separator' => 'before'
				]
			);
		$this->end_controls_section();

		/* Begin icon Style */
		$this->start_controls_section(
            'icon_style',
            [
                'label' => esc_html__( 'Icon', 'retirio' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );
            
			$this->add_responsive_control(
				'size_icon',
				[
					'label' 		=> esc_html__( 'Size', 'retirio' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px'],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box .icon i' => 'font-size: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .ova-icon-box .icon svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->start_controls_tabs( 'tabs_icon_style' );
				
				$this->start_controls_tab(
		            'tab_icon_normal',
		            [
		                'label' => esc_html__( 'Normal', 'retirio' ),
		            ]
		        );
                     
                     $this->add_control(
						'icon_color',
						[
							'label' 	=> esc_html__( 'Color', 'retirio' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box .icon i' => 'color: {{VALUE}};',
								'{{WRAPPER}} .ova-icon-box .icon svg, {{WRAPPER}} .ova-icon-box .icon svg path' => 'fill : {{VALUE}};'
							],
						]
					);

					$this->add_control(
						'icon_bgcolor',
						[
							'label' 	=> esc_html__( 'Background Color', 'retirio' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box .icon' => 'background-color: {{VALUE}};',
							],
						]
					);

		        $this->end_controls_tab();

		        $this->start_controls_tab(
		            'tab_icon_hover',
		            [
		                'label' => esc_html__( 'Hover', 'retirio' ),
		            ]
		        );

		             $this->add_control(
						'icon_color_hover',
						[
							'label' 	=> esc_html__( 'Color Hover', 'retirio' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box:hover .icon i' => 'color: {{VALUE}};',
								'{{WRAPPER}} .ova-icon-box:hover .icon svg, {{WRAPPER}} .ova-icon-box:hover .icon svg path' => 'fill : {{VALUE}};'
							],
						]
					);

					$this->add_control(
						'icon_bgcolor_hover',
						[
							'label' 	=> esc_html__( 'Background Color Hover', 'retirio' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box:hover .icon, {{WRAPPER}} .ova-icon-box-active:hover .icon' => 'background-color: {{VALUE}};',
							],
						]
					);

		        $this->end_controls_tab();

		    $this->end_controls_tabs();

	        $this->add_responsive_control(
	            'icon_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'retirio' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-icon-box .icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End icon style */

		/* Begin text number Style */
		$this->start_controls_section(
            'text_number_style',
            [
                'label' => esc_html__( 'Text Number', 'retirio' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
                'condition' => [
                	'template' => 'template1'
                ]
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'text_number_typography',
					'selector' 	=> '{{WRAPPER}} .ova-icon-box .text-number',
				]
			);

			$this->add_control(
				'text_number_color',
				[
					'label' 	=> esc_html__( 'Color', 'retirio' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box .text-number' => ' -webkit-text-stroke-color: {{VALUE}};',
					],
				]
			);

        $this->end_controls_section();
		/* End text number style */

		/* Begin title Style */
		$this->start_controls_section(
            'title_style',
            [
                'label' => esc_html__( 'Title', 'retirio' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography',
					'selector' 	=> '{{WRAPPER}} .ova-icon-box .title',
				]
			);

			$this->add_control(
				'title_color',
				[
					'label' 	=> esc_html__( 'Color', 'retirio' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box .title' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'title_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'retirio' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box:hover .title, {{WRAPPER}} .ova-icon-box-active .title' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'title_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'retirio' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-icon-box .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End title style */

		/* Begin description Style */
		$this->start_controls_section(
            'description_style',
            [
                'label' => esc_html__( 'Description', 'retirio' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'description_typography',
					'selector' 	=> '{{WRAPPER}} .ova-icon-box .description',
				]
			);

			$this->add_control(
				'description_color',
				[
					'label' 	=> esc_html__( 'Color', 'retirio' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box .description' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'description_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'retirio' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box:hover .description, {{WRAPPER}} .ova-icon-box-active .description' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'description_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'retirio' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-icon-box .description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End description style */

		/* Begin Icon Box Style */
		$this->start_controls_section(
            'icon_box_style',
            [
                'label' => esc_html__( 'Ova Icon Box', 'retirio' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->start_controls_tabs( 'tabs__style' );
				
				$this->start_controls_tab(
		            'tab_icon_box_normal',
		            [
		                'label' => esc_html__( 'Normal', 'retirio' ),
		            ]
		        );

		            $this->add_control(
						'card_bgcolor',
						[
							'label' 	=> esc_html__( 'Background Color', 'retirio' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box' => 'background-color: {{VALUE}};',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Box_Shadow::get_type(),
						[
							'name' => 'box_shadow_card',
							'label' => __( 'Box Shadow', 'retirio' ),
							'selector' => '{{WRAPPER}} .ova-icon-box',
						]
				    );

		        $this->end_controls_tab();

		        $this->start_controls_tab(
		            'tab_icon_box_hover',
		            [
		                'label' => esc_html__( 'Hover', 'retirio' ),
		            ]
		        );

				    $this->add_control(
						'card_bgcolor_hover',
						[
							'label' 	=> esc_html__( 'Background Color Hover', 'retirio' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box:hover:after, {{WRAPPER}} .ova-icon-box-active:after' => 'background-color: {{VALUE}};',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Box_Shadow::get_type(),
						[
							'name' => 'box_shadow_card_hover',
							'label' => __( 'Box Shadow Hover', 'retirio' ),
							'selector' => '{{WRAPPER}} .ova-icon-box:hover',
						]
				    );

		        $this->end_controls_tab();

		    $this->end_controls_tabs();

			$this->add_control(
				'card_hover_animation',
				[
					'label' => __( 'Hover Animation', 'retirio' ),
					'type' => \Elementor\Controls_Manager::HOVER_ANIMATION,
					'prefix_class' => 'elementor-animation-',
					'default'      => 'none',
					'separator'    => 'before'
				]
			);

		    $this->add_responsive_control(
	            'card_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'retirio' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-icon-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );
            
            // Box Background Image
	        $this->add_responsive_control(
	            'box_background_image_heading',
	            [
	                'label' 		=> esc_html__( 'Box Background Image', 'retirio' ),
	                'type' 			=> Controls_Manager::HEADING,
	                'condition' => [
						'template' => [
							'template2',
						]
					],
					'separator' => 'before'
	            ]
	        );

		    $this->add_responsive_control(
				'background_image_opacity',
				[
					'label' 		=> esc_html__( 'Opacity', 'retirio' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 0.5,
							'step' => 0.02,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box:hover .mask' => 'opacity: {{SIZE}};',
					],
					'condition' => [
						'template' => [
							'template2',
						]
					]
				]
			);

        $this->end_controls_section();
		/* End icon box style */
		
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		$template         =    $settings['template'];
		$active           =    isset( $settings['icon_box_active'] ) ? $settings['icon_box_active'] : '';
        
        $text_number      =    isset( $settings['text_number'] ) ? $settings['text_number'] : '' ;
		$title            =    $settings['title'];
		$description      =    $settings['description'];
		$icon             =    $settings['icon'];
		$link             =    $settings['link'];
		$nofollow         =    ( isset( $link['nofollow'] ) && $link['nofollow'] ) ? 'rel=nofollow' : '';
		$target           =    ( isset( $link['is_external'] ) && $link['is_external'] !== '' ) ? 'target=_blank' : '';

		$url_bg_image     =    ( isset( $settings['background_image_box'] ) && $settings['background_image_box'] ) ? $settings['background_image_box']['url'] : '';  

		?>
            

	 	    <div class="ova-icon-box ova-icon-box-<?php echo esc_attr( $template ); ?> <?php if( $active === 'yes' ) echo 'ova-icon-box-active'?>">

                <div class="mask"
                    <?php if (!empty( $url_bg_image )): ?> 
		 	    	 	style="background-image: url(<?php echo esc_attr( $url_bg_image ) ; ?>)"
		 	    	<?php endif;?>
                >	
                </div>

                <?php if( ( $text_number != '' ) && $template === 'template1' ) : ?>
	            	<div class="text-number">
					    <?php echo esc_html( $text_number ); ?>
	            	</div>
	            <?php endif;?>

				<?php if (!empty( $icon )): ?>
	            	<div class="icon">
	            		<?php 
					        \Elementor\Icons_Manager::render_icon( $icon, [ 'aria-hidden' => 'true' ] );
					    ?>
	            	</div>
	            <?php endif;?>

	            <?php if(!empty( $link['url'])) : ?>
				  <a href="<?php echo esc_url( $link['url'] ); ?> " <?php echo esc_attr( $target ); ?> <?php echo esc_attr( $nofollow ); ?> title="<?php echo esc_attr( $title ); ?>">
			    <?php endif; ?>
		            <?php if (!empty( $title )): ?>
						<h4 class="title">
							<?php echo esc_html( $title ); ?>
						</h4>
					<?php endif;?>
				<?php if(!empty( $link['url'])) : ?>
					</a>
				<?php endif; ?>

				<?php if (!empty( $description )): ?>
					<p class="description">
						<?php echo esc_html( $description ); ?>
					</p>
				<?php endif;?>

		    </div>	    


		<?php
	}

	
}
$widgets_manager->register( new Retirio_Elementor_Ova_Icon_Box() );