<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Retirio_Elementor_Ova_Image_Box extends Widget_Base {

	
	public function get_name() {
		return 'retirio_elementor_ova_image_box';
	}

	
	public function get_title() {
		return esc_html__( 'Ova Image Box', 'retirio' );
	}

	
	public function get_icon() {
		return 'eicon-image-box';
	}

	
	public function get_categories() {
		return [ 'retirio' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'retirio' ),
			]
		);	
			
			
			// Add Class control
			$this->add_control(
				'ova_image_box',
				[
					'label' => esc_html__( 'Choose Image', 'retirio' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'default' => [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					],
				]
			);

			$this->add_control(
				'image_title',
				[
					'label' => esc_html__( 'Title', 'retirio' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'default' => esc_html__( 'Innovative interior designs', 'retirio' ),
					'placeholder' => esc_html__( 'Innovative interior designs', 'retirio' ),
				]
			);

			$this->add_responsive_control(
				'align_item',
				[
					'label' 	=> esc_html__( 'Alignment', 'retirio' ),
					'type' 		=> \Elementor\Controls_Manager::CHOOSE,
					'options' 	=> [
						'left' => [
							'title' => esc_html__( 'Left', 'retirio' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'retirio' ),
							'icon' 	=> 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'retirio' ),
							'icon' 	=> 'eicon-text-align-right',
						],
					],
				
					'toggle' 	=> true,
					'selectors' => [
						'{{WRAPPER}} .ova-image-box .title' => 'text-align: {{VALUE}}',

					],
				]
			);


		$this->end_controls_section();

		/**
		 * Title Style Tab
		 */
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Title', 'retirio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
			//padding + typo + align + box-shadow
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'title_typography',
					'selector' => '{{WRAPPER}} .ova-image-box .title',
				]
			);

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Color', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image-box .title' => 'color : {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'title_color_hover',
				[
					'label' => esc_html__( 'Color hover', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image-box:hover .title' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'ova_title_background',
				[
					'label' => esc_html__( 'Background', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image-box .title-box' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'ova_title_background_hover',
				[
					'label' => esc_html__( 'Background Hover', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image-box .title-box .mask' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'title_padding',
				[
					'label' => esc_html__( 'Padding', 'retirio' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-image-box .title-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			
			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'title_box_shadow',
					'label' => esc_html__( 'Box Shadow', 'retirio' ),
					'selector' => '{{WRAPPER}}  .ova-image-box .title-box',
				]
			);

        $this->end_controls_section(); 
		// End tab title

		$this->start_controls_section(
			'section_image_style',
			[
				'label' => esc_html__( 'Image', 'retirio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'card_hover_animation',
				[
					'label' => __( 'Hover Animation', 'retirio' ),
					'type' => \Elementor\Controls_Manager::HOVER_ANIMATION,
					'prefix_class' => 'elementor-animation-',
					'default'      => 'none',
				]
			);

        $this->end_controls_section(); 
		
	}

	// Render Template Here
	protected function render() {

		$settings  = $this->get_settings();

		$title     = $settings['image_title'];
		$image_url =  $settings['ova_image_box']['url'];

		?>
		<div class="ova-image-box">
			<img src="<?php echo esc_attr( $image_url ); ?>" class="ova-image" alt="<?php esc_attr( $title ); ?>">
			<?php if( $title != '' ): ?>
				<div class="title-box">
					<h4 class="title"> <?php echo esc_html($title); ?> </h4>
					<div class="mask"></div>
				</div>
				
			<?php endif; ?>
			
		</div>
		 	
		<?php
	}

	
}
$widgets_manager->register( new Retirio_Elementor_Ova_Image_Box() );