<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Retirio_Elementor_Testimonial extends Widget_Base {

	public function get_name() {
		return 'retirio_elementor_testimonial';
	}

	public function get_title() {
		return esc_html__( 'Ova Testimonial', 'retirio' );
	}

	public function get_icon() {
		return 'eicon-testimonial';
	}

	public function get_categories() {
		return [ 'retirio' ];
	}

	public function get_script_depends() {
		return [ 'retirio-elementor-testimonial' ];
	}

	protected function register_controls() {


		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'retirio' ),
			]
		);

			$this->add_control(
				'version',
				[
					'label' => esc_html__( 'Version', 'retirio' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'version_2',
					'options' => [
						'version_1' => esc_html__( 'Version 1', 'retirio' ),
						'version_2' => esc_html__( 'Version 2', 'retirio' ),
						'version_3' => esc_html__( 'Version 3', 'retirio' ),
					]
				]
			);

			$this->add_control(
				'icon_quote',
				[
					'label' 	=> esc_html__( 'Icon', 'retirio' ),
					'type' 		=> \Elementor\Controls_Manager::ICONS,
					'default' 	=> [
						'value' 	=> 'flaticon flaticon-quotes',
						'library' 	=> 'all',
					],
					'condition' => [
							'version!' => 'version_3',
					],
				]
			);


			$repeater = new \Elementor\Repeater();


				$repeater->add_control(
					'name_author',
					[
						'label'   => esc_html__( 'Author Name', 'retirio' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
					]
				);

				$repeater->add_control(
					'job',
					[
						'label'   => esc_html__( 'Job', 'retirio' ),
						'type'    => \Elementor\Controls_Manager::TEXT,

					]
				);	
			
					$repeater->add_control(
						'rating',
						[
							'label' => esc_html__( 'Rating', 'retirio' ),
							'type' => Controls_Manager::NUMBER,
							'min' => 0,
							'max' => 10,
							'step' => 0.1,
							'default' => 5,
							'dynamic' => [
								'active' => true,
							],
						]
					);
			
					$repeater->add_control(
						'star_style',
						[
							'label' => esc_html__( 'Icon', 'retirio' ),
							'type' => Controls_Manager::SELECT,
							'options' => [
								'star_fontawesome' => 'Font Awesome',
								'star_unicode' => 'Unicode',
							],
							'default' => 'star_fontawesome',
							'render_type' => 'template',
							'prefix_class' => 'elementor--star-style-',
							'separator' => 'before',
						]
					);
			
					$repeater->add_control(
						'unmarked_star_style',
						[
							'label' => esc_html__( 'Unmarked Style', 'retirio' ),
							'type' => Controls_Manager::CHOOSE,
							'options' => [
								'solid' => [
									'title' => esc_html__( 'Solid', 'retirio' ),
									'icon' => 'eicon-star',
								],
								'outline' => [
									'title' => esc_html__( 'Outline', 'retirio' ),
									'icon' => 'eicon-star-o',
								],
							],
							'default' => 'solid',
						]
					);

				$repeater->add_control(
					'image_author',
					[
						'label'   => esc_html__( 'Author Image', 'retirio' ),
						'type'    => \Elementor\Controls_Manager::MEDIA,
						'default' => [
							'url' => Utils::get_placeholder_image_src(),
						],
					]
				);

				$repeater->add_control(
					'testimonial',
					[
						'label'   => esc_html__( 'Testimonial ', 'retirio' ),
						'type'    => \Elementor\Controls_Manager::TEXTAREA,
						'default' => esc_html__( '"Sed ullamcorper morbi tincidunt or massa eget egestas purus. Non nisi est sit amet facilisis magna etiam."', 'retirio' ),
					]
				);

				$repeater->add_control(
					'background_color_item',
					[
						'label'     => esc_html__( 'Background color item', 'retirio' ),
						'type'      => Controls_Manager::COLOR,
					]
				);

				$this->add_control(
					'tab_item',
					[
						'label'       => esc_html__( 'Items Testimonial', 'retirio' ),
						'type'        => Controls_Manager::REPEATER,
						'fields'      => $repeater->get_controls(),
						'default' => [
							[
								'name_author' => esc_html__('Kevin martin', 'retirio'),
								'job' => esc_html__('Our customer', 'retirio'),
								'testimonial' => esc_html__('Through a unique combination of engineering, construction design disciplines and expertise, Concor delivers world class infrastructure solutions.', 'retirio'),
							],
							[
								'name_author' => esc_html__('Jessica brown ', 'retirio'),
								'job' => esc_html__('Our customer', 'retirio'),
								'testimonial' => esc_html__('Through a unique combination of engineering, construction design disciplines and expertise, Concor delivers world class infrastructure solutions.', 'retirio'),
							],
							[
								'name_author' => esc_html__('Mike hardson', 'retirio'),
								'job' => esc_html__('Our customer', 'retirio'),
								'testimonial' => esc_html__('Through a unique combination of engineering, construction design disciplines and expertise, Concor delivers world class infrastructure solutions.', 'retirio'),
							],
						],
						'title_field' => '{{{ name_author }}}',
						'condition' => [
							'version' => 'version_1',
						],
					]
				);


				// tab_item_2
				$repeater_v2 = new \Elementor\Repeater();


				$repeater_v2->add_control(
					'name_author',
					[
						'label'   => esc_html__( 'Author Name', 'retirio' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
					]
				);

				$repeater_v2->add_control(
					'job',
					[
						'label'   => esc_html__( 'Job', 'retirio' ),
						'type'    => \Elementor\Controls_Manager::TEXT,

					]
				);	
					
				$repeater_v2->add_control(
					'image_author',
					[
						'label'   => esc_html__( 'Author Image', 'retirio' ),
						'type'    => \Elementor\Controls_Manager::MEDIA,
						'default' => [
							'url' => Utils::get_placeholder_image_src(),
						],
					]
				);

				$repeater_v2->add_control(
					'testimonial',
					[
						'label'   => esc_html__( 'Testimonial ', 'retirio' ),
						'type'    => \Elementor\Controls_Manager::TEXTAREA,
						'default' => esc_html__( '"Sed ullamcorper morbi tincidunt or massa eget egestas purus. Non nisi est sit amet facilisis magna etiam."', 'retirio' ),
					]
				);

				$this->add_control(
					'tab_item_v2',
					[
						'label'       => esc_html__( 'Items Testimonial', 'retirio' ),
						'type'        => Controls_Manager::REPEATER,
						'fields'      => $repeater_v2->get_controls(),
						'default' => [
							[
								'name_author' => esc_html__('Kevin martin', 'retirio'),
								'job' => esc_html__('Our customer', 'retirio'),
								'testimonial' => esc_html__('Through a unique combination of engineering, construction design disciplines and expertise, Concor delivers world class infrastructure solutions.', 'retirio'),
							],
							[
								'name_author' => esc_html__('Jessica brown ', 'retirio'),
								'job' => esc_html__('Our customer', 'retirio'),
								'testimonial' => esc_html__('Through a unique combination of engineering, construction design disciplines and expertise, Concor delivers world class infrastructure solutions.', 'retirio'),
							],
							[
								'name_author' => esc_html__('Mike hardson', 'retirio'),
								'job' => esc_html__('Our customer', 'retirio'),
								'testimonial' => esc_html__('Through a unique combination of engineering, construction design disciplines and expertise, Concor delivers world class infrastructure solutions.', 'retirio'),
							],
						],
						'title_field' => '{{{ name_author }}}',
						'condition' => [
							'version' => 'version_2',
						],
					]
				);

				// tab_item_3
				$repeater_v3 = new \Elementor\Repeater();


				$repeater_v3->add_control(
					'name_author',
					[
						'label'   => esc_html__( 'Author Name', 'retirio' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
					]
				);

				$repeater_v3->add_control(
					'job',
					[
						'label'   => esc_html__( 'Job', 'retirio' ),
						'type'    => \Elementor\Controls_Manager::TEXT,

					]
				);	
					
				$repeater_v3->add_control(
					'image_author',
					[
						'label'   => esc_html__( 'Author Image', 'retirio' ),
						'type'    => \Elementor\Controls_Manager::MEDIA,
						'default' => [
							'url' => Utils::get_placeholder_image_src(),
						],
					]
				);

				$repeater_v3->add_control(
					'testimonial',
					[
						'label'   => esc_html__( 'Testimonial ', 'retirio' ),
						'type'    => \Elementor\Controls_Manager::TEXTAREA,
						'default' => esc_html__( '"Sed ullamcorper morbi tincidunt or massa eget egestas purus. Non nisi est sit amet facilisis magna etiam."', 'retirio' ),
					]
				);

				$this->add_control(
					'tab_item_v3',
					[
						'label'       => esc_html__( 'Items Testimonial', 'retirio' ),
						'type'        => Controls_Manager::REPEATER,
						'fields'      => $repeater_v2->get_controls(),
						'default' => [
							[
								'name_author' => esc_html__('Kevin martin', 'retirio'),
								'job' => esc_html__('Customer', 'retirio'),
								'testimonial' => esc_html__('This is due to their excellent service, competitive pricing and customer support. It’s throughly refresing to get such a personal touch. Duis aute lorem ipsum is simply free text irure dolor in velit esse.', 'retirio'),
							],
							[
								'name_author' => esc_html__('Jessica brown ', 'retirio'),
								'job' => esc_html__('Customer', 'retirio'),
								'testimonial' => esc_html__('This is due to their excellent service, competitive pricing and customer support. It’s throughly refresing to get such a personal touch. Duis aute lorem ipsum is simply free text irure dolor in velit esse.', 'retirio'),
							],
							[
								'name_author' => esc_html__('Mike hardson', 'retirio'),
								'job' => esc_html__('Customer', 'retirio'),
								'testimonial' => esc_html__('This is due to their excellent service, competitive pricing and customer support. It’s throughly refresing to get such a personal touch. Duis aute lorem ipsum is simply free text irure dolor in velit esse.', 'retirio'),
							],
						],
						'title_field' => '{{{ name_author }}}',
						'condition' => [
							'version' => 'version_3',
						],
					]
				);
			

		$this->end_controls_section();

		/*****************  END SECTION CONTENT ******************/


		/*****************************************************************
						START SECTION ADDITIONAL
		******************************************************************/

		$this->start_controls_section(
			'section_additional_options',
			[
				'label' => esc_html__( 'Additional Options', 'retirio' ),
			]
		);


		/***************************  VERSION 1 ***********************/
			$this->add_control(
				'margin_items',
				[
					'label'   => esc_html__( 'Margin Right Items', 'retirio' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 30,
				]
				
			);

			$this->add_control(
				'item_number',
				[
					'label'       => esc_html__( 'Item Number', 'retirio' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Number Item', 'retirio' ),
					'default'     => 3,
					'condition' => [
						'version' => 'version_1',
					],
				]
			);

			$this->add_control(
				'item_number_2',
				[
					'label'       => esc_html__( 'Item Number', 'retirio' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Number Item', 'retirio' ),
					'default'     => 1,
					'condition' => [
						'version' => 'version_2',
						'version' => 'version_3',
					],
				]
			);

	

			$this->add_control(
				'slides_to_scroll',
				[
					'label'       => esc_html__( 'Slides to Scroll', 'retirio' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'retirio' ),
					'default'     => 1,
				]
			);

			$this->add_control(
				'pause_on_hover',
				[
					'label'   => esc_html__( 'Pause on Hover', 'retirio' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'retirio' ),
						'no'  => esc_html__( 'No', 'retirio' ),
					],
					'frontend_available' => true,
				]
			);


			$this->add_control(
				'infinite',
				[
					'label'   => esc_html__( 'Infinite Loop', 'retirio' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'retirio' ),
						'no'  => esc_html__( 'No', 'retirio' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay',
				[
					'label'   => esc_html__( 'Autoplay', 'retirio' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'retirio' ),
						'no'  => esc_html__( 'No', 'retirio' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay_speed',
				[
					'label'     => esc_html__( 'Autoplay Speed', 'retirio' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => 3000,
					'step'      => 500,
					'condition' => [
						'autoplay' => 'yes',
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'smartspeed',
				[
					'label'   => esc_html__( 'Smart Speed', 'retirio' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 500,
				]
			);

			$this->add_control(
				'dot_control',
				[
					'label'   => esc_html__( 'Show Dots', 'retirio' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'no',
					'options' => [
						'yes' => esc_html__( 'Yes', 'retirio' ),
						'no'  => esc_html__( 'No', 'retirio' ),
					],
					'frontend_available' => true,
				]
			);

		$this->end_controls_section();

		/****************************  END SECTION ADDITIONAL *********************/

		/*************  SECTION NAME JOB. *******************/
		$this->start_controls_section(
			'section_general',
			[
				'label' => esc_html__( 'General', 'retirio' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'dot_active_color',
				[
					'label'     => esc_html__( 'Dot Active Color', 'retirio' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_2 .slide-testimonials .owl-dots .owl-dot.active span' => 'background : {{VALUE}};',
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot.active span' => 'background : {{VALUE}};',
						
					],
				]
			);

			$this->add_control(
				'back_ground_content_color',
				[
					'label'     => esc_html__( 'Background Item', 'retirio' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info' => 'background : {{VALUE}};',	
					],
				]
			);

			// 
			
			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'box_shadow_content',
					'label' => __( 'Box Shadow', 'retirio' ),
					'selector' => '{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-item.active .client_info ',
				]
		    );


			$this->add_responsive_control(
				'background_item_margin',
				[
					'label'      => esc_html__( 'Margin', 'retirio' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'background_item_padding',
				[
					'label'      => esc_html__( 'Padding Item', 'retirio' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'background_item_padding_box',
				[
					'label'      => esc_html__( 'Padding Item Box', 'retirio' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial.version_1 .slide-testimonials .item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'condition' 	=> [
						'version' 		=> 'version_1',
					]
				]
			);

		$this->end_controls_section();
		###############  end section job  ###############


		/*************  SECTION content testimonial  *******************/
		$this->start_controls_section(
			'section_content_testimonial',
			[
				'label' => esc_html__( 'Content Testimonial', 'retirio' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     => 'content_testimonial_typography',
					'selector' => '{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info p.evaluate',
				]
			);

			$this->add_control(
				'content_color',
				[
					'label'     => esc_html__( 'Color', 'retirio' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info p.evaluate' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'content_margin',
				[
					'label'      => esc_html__( 'Margin', 'retirio' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info p.evaluate' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'content_padding',
				[
					'label'      => esc_html__( 'Padding', 'retirio' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info p.evaluate' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);


		$this->end_controls_section();
		###############  end section content testimonial  ###############


		/*************  SECTION NAME AUTHOR. *******************/
		$this->start_controls_section(
			'section_author_name',
			[
				'label' => esc_html__( 'Author Name', 'retirio' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     => 'author_name_typography',
					'selector' => '{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .name',
				]
			);

			$this->add_control(
				'author_name_color',
				[
					'label'     => esc_html__( 'Color Author', 'retirio' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'
						{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .name' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'author_name_margin',
				[
					'label'      => esc_html__( 'Margin', 'retirio' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'author_name_padding',
				[
					'label'      => esc_html__( 'Padding', 'retirio' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .name' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		###############  end section author  ###############

					
		/*************  SECTION  avatar. *******************/
		$this->start_controls_section(
			'section_Avatar',
			[
				'label' => esc_html__( 'Avatar', 'retirio' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		    $this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border_avatar',
					'label' => esc_html__( 'Border Avatar', 'retirio' ),
					'selector' => '{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .client img',
				]
			);

			$this->add_responsive_control(
				'border_radius_avatar',
				array(
					'label'      => esc_html__( 'Border Radius', 'retirio' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px', '%' ),
					'selectors'  => array(
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .client img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				)
			);

			$this->add_control(
				'avatar_max_width',
				[
					'label' => esc_html__( 'Max Width', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 1,
							'max' => 300,
							'step' => 1,
						]
					],
					
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .client img' => 'max-width: {{SIZE}}{{UNIT}}',
					],
					
				]
			);

			$this->add_control(
				'avatar_min_height',
				[
					'label' => esc_html__( 'Min Height', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 1,
							'max' => 300,
							'step' => 1,
						]
					],
					
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .client img' => 'min-height: {{SIZE}}{{UNIT}}',
					],
					
				]
			);

		$this->end_controls_section();
		###############  end section Avatar  ###############


		/*************  SECTION NAME JOB. *******************/
		$this->start_controls_section(
			'section_job',
			[
				'label' => esc_html__( 'Job', 'retirio' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     => 'job_typography',
					'selector' => '{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .job',
				]
			);

			$this->add_control(
				'job_color',
				[
					'label'     => esc_html__( 'Color Job', 'retirio' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'
						{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .job' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'job_margin',
				[
					'label'      => esc_html__( 'Margin', 'retirio' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .job' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'job_padding',
				[
					'label'      => esc_html__( 'Padding', 'retirio' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .job' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);


		$this->end_controls_section();
		###############  end section job  ###############
		
		// ====== stytels stars ===== 
		$this->start_controls_section(
			'section_stars_style',
			[
				'label' => esc_html__( 'Rating Stars', 'retirio' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' 	=> [
					'version' 		=> 'version_1',
				]
			]
		);

			$this->add_responsive_control(
				'icon_size',
				[
					'label' => esc_html__( 'Size', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .elementor-star-rating' => 'font-size: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_responsive_control(
				'icon_space',
				[
					'label' => esc_html__( 'Spacing', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 50,
						],
					],
					'selectors' => [
						'body:not(.rtl) {{WRAPPER}} .elementor-star-rating i:not(:last-of-type)' => 'margin-right: {{SIZE}}{{UNIT}}',
						'body.rtl {{WRAPPER}} .elementor-star-rating i:not(:last-of-type)' => 'margin-left: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_control(
				'stars_color',
				[
					'label' => esc_html__( 'Color', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_1 .slide-testimonials .owl-item .item .client_info .ova-rating .elementor-star-rating i::before' => 'color: {{VALUE}}',
						
					],
					'separator' => 'before',
				]
			);

			$this->add_control(
				'stars_unmarked_color',
				[
					'label' => esc_html__( 'Unmarked Color', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .elementor-star-rating i' => 'color: {{VALUE}}',
					],
				]
			);

		$this->end_controls_section();

		// STYLE QUOTE ICON 
		$this->start_controls_section(
			'section_quote_icon',
			[
				'label' => esc_html__( 'Quote icon', 'retirio' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
							'version!' => 'version_3',
				],
			]
		);

			$this->add_control(
				'quote_color',
				[
					'label'     => esc_html__( 'Quote Job', 'retirio' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .icon-quote i' => 'color : {{VALUE}};',
					],
					
				]
			);

			$this->add_responsive_control(
				'quote_size',
				[
					'label' => esc_html__( 'Size', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .icon-quote i:before' => 'font-size: {{SIZE}}{{UNIT}}',
					],
				]
			);


		$this->end_controls_section();

		// DOT NAV
		// STYLE QUOTE dot
		$this->start_controls_section(
			'section_dot_control',
			[
				'label' => esc_html__( 'Dot control', 'retirio' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
							'dot_control' => 'yes',
				],
			]
		);

			$this->add_control(
				'dot_color',
				[
					'label'     => esc_html__( 'Color', 'retirio' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot span' => 'background-color : {{VALUE}};',
					],
					
				]
			);

			$this->add_control(
				'dot_color_active',
				[
					'label'     => esc_html__( 'Color active', 'retirio' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot.active span' => 'background-color : {{VALUE}};',
					],
					
				]
			);

			$this->add_responsive_control(
				'dot_control_size',
				[
					'label' => esc_html__( 'Size', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot span' => 'width: {{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'dot_control_active_size',
				[
					'label' => esc_html__( 'Active size', 'retirio' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 1,
							'max' => 300,
							'step' => 1,
						]
					],
					
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot.active span' => 'width: {{SIZE}}{{UNIT}};',
					],
					
				]
			);


		$this->end_controls_section();

	}



	protected function get_rating($rating) {

		$settings = $this->get_settings();
		$rating_scale = 5;

		return [ $rating, $rating_scale ];
	}

	protected function render_stars( $icon, $rating ) {
		$rating_data = $this->get_rating($rating);
		$rating = (float) $rating_data[0];
		$floored_rating = floor( $rating );
		$stars_html = '';

		for ( $stars = 1.0; $stars <= $rating_data[1]; $stars++ ) {
			if ( $stars <= $floored_rating ) {
				$stars_html .= '<i class="elementor-star-full">' . $icon . '</i>';
			} elseif ( $floored_rating + 1 === $stars && $rating !== $floored_rating ) {
				$stars_html .= '<i class="elementor-star-' . ( $rating - $floored_rating ) * 10 . '">' . $icon . '</i>';
			} else {
				$stars_html .= '<i class="elementor-star-empty">' . $icon . '</i>';
			}
		}

		return $stars_html;
	}


	protected function render() {

		$settings = $this->get_settings();
		$version = $settings['version'];

		if( $version == 'version_1' ) {

			$tab_item = $settings['tab_item'];

		} elseif( $version == 'version_2' ) {

			$tab_item = $settings['tab_item_v2'];

		} else {

			$tab_item = $settings['tab_item_v3'];

		}


		
		if($version == 'version_1'){
			
			$data_options['items']  = $settings['item_number'];
		} else{
			$data_options['items']  = $settings['item_number_2'];
		}

		$data_options['slideBy']            = $settings['slides_to_scroll'];
		$data_options['margin']             = $settings['margin_items'];
		$data_options['autoplayHoverPause'] = $settings['pause_on_hover'] === 'yes' ? true : false;
		$data_options['loop']               = $settings['infinite'] === 'yes' ? true : false;
		$data_options['autoplay']           = $settings['autoplay'] === 'yes' ? true : false;
		$data_options['autoplayTimeout']    = $settings['autoplay_speed'];
		$data_options['smartSpeed']         = $settings['smartspeed'];
		$data_options['dots']               = $settings['dot_control'] === 'yes' ? true : false;
		$data_options['rtl']				= is_rtl() ? true: false;



?>


		<?php if( $version === 'version_1' ):?>

			<section class="ova-testimonial version_1">

					<div class="slide-testimonials owl-carousel owl-theme " data-options="<?php echo esc_attr(json_encode($data_options)); ?>">
						<?php if(!empty($tab_item)) : foreach ($tab_item as $item) : ?>
							<div class="item">
								<div class="line-right" style="background-color: <?php echo esc_attr($item['background_color_item']); ?>;"></div>
								<div class="line-bottom" style="background-color: <?php echo esc_attr($item['background_color_item']); ?>;"></div>
								<div class="client_info">
						
									<div class="info">

										<div class="client">
											<?php if( $item['image_author'] != '' ) { ?>
												<?php $alt = isset($item['name_author']) && $item['name_author'] ? $item['name_author'] : esc_html__( 'testimonial','retirio' ); ?>
												<img src="<?php echo esc_attr($item['image_author']['url']); ?>" alt="<?php echo esc_attr( $alt ); ?>" >
											<?php } ?>
										</div>
										<div class="name-job">
											
											<?php if( $item['name_author'] != '' ) { ?>
												<p class="name second_font">
													<?php echo esc_html($item['name_author']) ?>
												</p>
											<?php } ?>

											<?php if( $item['job'] != '' ) { ?>
												<p class="job">
													<?php echo esc_html($item['job']) ?>
												</p>
											<?php } ?>
											<!-- rating -->
											<?php 
												$icon = '&#xE934;';
												$rating_data = $this->get_rating($item['rating']);
												$textual_rating = $rating_data[0] . '/' . $rating_data[1];
												$rating = (float) $item['rating'];
												$unmarked_star_style = $item['unmarked_star_style'];
												$star_style = $item['star_style'];
												
												if ( 'star_fontawesome' === $star_style ) {
													if ( 'outline' === $unmarked_star_style ) {
														$icon = '&#xE933;';
													}
												} elseif ( 'star_unicode' === $star_style ) {
													$icon = '&#9733;';
										
													if ( 'outline' === $unmarked_star_style ) {
														$icon = '&#9734;';
													}
												}

												$stars_element = '<div class="elementor-star-rating" title="'.$textual_rating.'">' . $this->render_stars( $icon, $item['rating'] ) . ' </div>';
												
												?>
												<?php if($rating != 0) : ?>
													<div class="ova-rating <?php echo esc_html( $star_style ); ?>">
														<?php print_r ( $stars_element ); ?>
													</div>
												<?php endif ?>
												
													
												<?php
											
											?>
											<!-- end rating -->
										</div>
									</div><!-- end info -->
									
									<?php if( $item['testimonial'] != '' ) : ?>
									<p class="evaluate">
										<?php echo esc_html($item['testimonial']); ?>
									</p>
									<?php endif; ?>
									
									<div class="icon-quote">
										<?php \Elementor\Icons_Manager::render_icon( $settings['icon_quote'], [ 'aria-hidden' => 'true' ] );  ?>
									</div>
								</div>
							</div>
						<?php endforeach; endif; ?>
					</div>

			</section>

		<?php endif; ?>


		<?php if( $version === 'version_2' ):?>

			<section class="ova-testimonial version_2">

					<div class="slide-testimonials owl-carousel owl-theme " data-options="<?php echo esc_attr(json_encode($data_options)) ?>">
						<?php if(!empty($tab_item)) : foreach ($tab_item as $item) : ?>
							<div class="item">
								<div class="client_info">
									<?php if( $item['testimonial'] != '' ) : ?>
											<p class="evaluate second_font"><?php echo esc_html($item['testimonial']) ?></p>
									<?php endif; ?>

									<div class="testimonial">
										<div class="info">
											<div class="client">
												<?php if( $item['image_author'] != '' ) { ?>
													<?php $alt = isset($item['name_author']) && $item['name_author'] ? $item['name_author'] : esc_html__( 'testimonial','retirio' ); ?>
														<img src="<?php echo esc_attr($item['image_author']['url']) ?>" alt="<?php echo esc_attr( $alt ); ?>" >
												<?php } ?>
											</div>
											<div class="name-job">
												<?php if( $item['name_author'] != '' ) { ?>
												<p class="name second_font"><?php echo esc_html($item['name_author']) ?></p>
												<?php } ?>
												<?php if( $item['job'] != '' ) { ?>
												<p class="job"><?php echo esc_html($item['job']) ?></p>
												<?php } ?>
											</div>
										</div>
										<!-- end info -->
										<div class="icon-quote">
											<?php \Elementor\Icons_Manager::render_icon( $settings['icon_quote'], [ 'aria-hidden' => 'true' ] );  ?>
										</div>
									</div>
									
								</div>
							</div>
						<?php endforeach; endif; ?>
					</div>

			</section>
		<?php endif; ?>

		<?php if( $version === 'version_3' ):?>	
		
			<section class="ova-testimonial version_3">

					<div class="slide-testimonials owl-carousel owl-theme " data-options="<?php echo esc_attr(json_encode($data_options)) ?>">
						<?php if(!empty($tab_item)) : foreach ($tab_item as $item) : ?>
							<div class="item">
								<div class="client_info">
									<div class="client">
										<?php if( $item['image_author'] != '' ) { ?>
											<?php $alt = isset($item['name_author']) && $item['name_author'] ? $item['name_author'] : esc_html__( 'testimonial','retirio' ); ?>
												<img src="<?php echo esc_attr($item['image_author']['url']) ?>" alt="<?php echo esc_attr( $alt ); ?>" >
										<?php } ?>
									</div>
									<?php if( $item['testimonial'] != '' ) : ?>
										<p class="evaluate second_font"><?php echo esc_html($item['testimonial']) ?></p>
									<?php endif; ?>
									<div class="info">
										
										<div class="name-job">
											<?php if( $item['name_author'] != '' ) { ?>
											<p class="name second_font"><?php echo esc_html($item['name_author']) ?></p>
											<?php } ?>
											<?php if( $item['job'] != '' ) { ?>
											<p class="job"><?php echo esc_html($item['job']) ?></p>
											<?php } ?>
										</div>
									</div>
										<!-- end info -->
									
								</div>
							</div>
						<?php endforeach; endif; ?>
					</div>

			</section>
		<?php endif; ?>
		
		<?php
	}
	// end render
}

$widgets_manager->register( new Retirio_Elementor_Testimonial() );

