<?php

class Retirio_Elementor {
	
	function __construct() {
            
		// Register Header Footer Category in Pane
	    add_action( 'elementor/elements/categories_registered', array( $this, 'retirio_add_category' ) );

	    add_action( 'elementor/frontend/after_register_scripts', array( $this, 'retirio_enqueue_scripts' ) );
		
		add_action( 'elementor/widgets/register', array( $this, 'retirio_include_widgets' ) );
		
		add_filter( 'elementor/controls/animations/additional_animations', array( $this, 'retirio_add_animations'), 10 , 0 );

		add_action( 'wp_print_footer_scripts', array( $this, 'retirio_enqueue_footer_scripts' ) );

		// load icons
		add_filter( 'elementor/icons_manager/additional_tabs', array( $this, 'retirio_icons_filters_new' ), 9999999, 1 );

		// Add Retirio fonts
		add_filter( 'elementor/fonts/groups', array( $this, 'retirio_font_groups' ), 9999999, 1 );
		add_filter( 'elementor/fonts/additional_fonts', array( $this, 'retirio_additional_fonts' ), 9999999, 1 );

		//Add icons social custom
		add_action( 'elementor/element/social-icons/section_social_hover/after_section_end', array( $this, 'retirio_social_icons_custom' ), 10, 2 );

		//Add text editor custom control style
		add_action( 'elementor/element/text-editor/section_style/after_section_end', array( $this, 'retirio_text_editor_custom' ), 10, 2 );

        //Add button custom control style ( hover effect )
		add_action( 'elementor/element/button/section_style/after_section_end', array( $this, 'retirio_button_custom' ), 10, 2 );

		//Add accordion custom control style
		add_action( 'elementor/element/accordion/section_toggle_style_content/after_section_end', array( $this, 'retirio_accordion_custom' ), 10, 2 );

	}
	
	function retirio_add_category(  ) {

	    \Elementor\Plugin::instance()->elements_manager->add_category(
	        'hf',
	        [
	            'title' => __( 'Header Footer', 'retirio' ),
	            'icon' => 'fa fa-plug',
	        ]
	    );

	    \Elementor\Plugin::instance()->elements_manager->add_category(
	        'retirio',
	        [
	            'title' => __( 'Retirio', 'retirio' ),
	            'icon' => 'fa fa-plug',
	        ]
	    );

	}

	function retirio_enqueue_scripts(){
        
        $files = glob(get_theme_file_path('/assets/js/elementor/*.js'));
        
        foreach ($files as $file) {
            $file_name = wp_basename($file);
            $handle    = str_replace(".js", '', $file_name);
            $src       = get_theme_file_uri('/assets/js/elementor/' . $file_name);
            if (file_exists($file)) {
                wp_register_script( 'retirio-elementor-' . $handle, $src, ['jquery'], false, true );
            }
        }


	}

	function retirio_include_widgets( $widgets_manager ) {
        $files = glob(get_theme_file_path('elementor/widgets/*.php'));
        foreach ($files as $file) {
            $file = get_theme_file_path('elementor/widgets/' . wp_basename($file));
            if (file_exists($file)) {
                require_once $file;
            }
        }
    }

    function retirio_add_animations(){
    	$animations = array(
            'Retirio' => array(
                'ova-move-up' 		=> esc_html__('Move Up', 'retirio'),
                'ova-move-down' 	=> esc_html__( 'Move Down', 'retirio' ),
                'ova-move-left'     => esc_html__('Move Left', 'retirio'),
                'ova-move-right'    => esc_html__('Move Right', 'retirio'),
                'ova-scale-up'      => esc_html__('Scale Up', 'retirio'),
                'ova-flip'          => esc_html__('Flip', 'retirio'),
                'ova-helix'         => esc_html__('Helix', 'retirio'),
                'ova-popup'			=> esc_html__( 'PopUp','retirio' )
            ),
        );

        return $animations;
    }

   

	function retirio_enqueue_footer_scripts(){
		// Font Icon
	    wp_enqueue_style('ovaicon', RETIRIO_URI.'/assets/libs/ovaicon/font/ovaicon.css', array(), null);

	    // Flaticon
	    wp_enqueue_style('ova-flaticon', RETIRIO_URI.'/assets/libs/flaticon/font/flaticon.css', array(), null);
	}

	function retirio_font_groups( $args = array() ) {

		$groups['retirio'] = esc_html__( 'Retirio', 'retirio' );
		return array_merge( $args, $groups );
	}

	function retirio_additional_fonts( $args = array() ) {

		$fonts['Reey'] 	= 'retirio';

		return array_merge( $args, $fonts );
	}
	
	

	public function retirio_icons_filters_new( $tabs = array() ) {

		$newicons = [];

		// Ovaicon
		$font_data['json_url'] = RETIRIO_URI.'/assets/libs/ovaicon/ovaicon.json';
		$font_data['name'] = 'ovaicon';

		$newicons[ $font_data['name'] ] = [
			'name'          => $font_data['name'],
			'label'         => esc_html__( 'Default', 'retirio' ),
			'url'           => '',
			'enqueue'       => '',
			'prefix'        => 'ovaicon-',
			'displayPrefix' => '',
			'ver'           => '1.0',
			'fetchJson'     => $font_data['json_url'],
		];

		// Flaticon
		$flaticon_data['json_url'] = RETIRIO_URI.'/assets/libs/flaticon/flaticon.json';
		$flaticon_data['name'] = 'flaticon';

		$newicons[ $flaticon_data['name'] ] = [
			'name'          => $flaticon_data['name'],
			'label'         => esc_html__( 'Flaticon', 'retirio' ),
			'url'           => '',
			'enqueue'       => '',
			'prefix'        => 'flaticon-',
			'displayPrefix' => '',
			'ver'           => '1.0',
			'fetchJson'     => $flaticon_data['json_url'],
		];

		return array_merge( $tabs, $newicons );

	}

	function retirio_social_icons_custom ( $element, $args ) {
	/** @var \Elementor\Element_Base $element */
	$element->start_controls_section(
		'ova_social_icons',
		[
			'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
			'label' => esc_html__( 'Ova Social Icon', 'retirio' ),
		]
	);

		$element->add_responsive_control(
            'ova_social_icons_display',
            [
                'label' 	=> esc_html__( 'Display', 'retirio' ),
                'type' 		=> \Elementor\Controls_Manager::CHOOSE,
                'options' 	=> [
                    'inline-block' => [
                        'title' => esc_html__( 'Block', 'retirio' ),
                        'icon' 	=> 'eicon-h-align-left',
                    ],
                    'inline-flex' => [
                        'title' => esc_html__( 'Flex', 'retirio' ),
                        'icon' 	=> 'eicon-h-align-center',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon.elementor-social-icon' => 'display: {{VALUE}}',
                ],
            ]
        );

		$element->end_controls_section();
	}

	// Ova text-editor custom 
    function retirio_text_editor_custom( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_tabs',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Text Editor', 'retirio' ),
			]
		);

			$element->add_responsive_control(
				'text_margin',
				[
					'label' 		=> esc_html__( 'Margin', 'retirio' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
					'{{WRAPPER}}  p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$element->add_responsive_control(
		        'text_padding',
		        [
		            'label' 		=> esc_html__( 'Padding', 'retirio' ),
		            'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
		            'size_units' 	=> [ 'px', '%', 'em' ],
		            'selectors' 	=> [
		             '{{WRAPPER}}  p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		            ],
		         ]
		    );

		$element->end_controls_section();
	}  
    
    // Ova button custom 
	function retirio_button_custom ( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_button',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Button', 'retirio' ),
			]
		);

			$element->add_control(
	            'button_bg_hover',
	            [
	                'label' 	=> esc_html__( 'Background Hover', 'retirio' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-button-wrapper .elementor-button:before' => 'background-color: {{VALUE}};',
	                ],
	            ]
	        );

	         $element->start_controls_tabs( 'tabs_custom_button_style' );
				
				$element->start_controls_tab(
		            'tab_custom_button_normal',
		            [
		                'label' => esc_html__( 'Normal', 'retirio' ),
		            ]
		        );

		            $element->add_responsive_control(
						'button_before_width',
						[
							'label' 		=> esc_html__( 'Width', 'retirio' ),
							'type' 			=> \Elementor\Controls_Manager::SLIDER,
							'size_units' 	=> ['px'],
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 20,
									'step' => 1,
								],
							],
							'selectors' => [
								'{{WRAPPER}} .elementor-button-wrapper .elementor-button:before' => 'width: {{SIZE}}{{UNIT}};',
							],
							'description' => esc_html__( '(px)', 'retirio' )
						]
					);

					 $element->add_responsive_control(
						'button_before_height',
						[
							'label' 		=> esc_html__( 'Height', 'retirio' ),
							'type' 			=> \Elementor\Controls_Manager::SLIDER,
							'size_units' 	=> ['px'],
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 20,
									'step' => 1,
								],
							],
							'selectors' => [
								'{{WRAPPER}} .elementor-button-wrapper .elementor-button:before' => 'height: {{SIZE}}{{UNIT}};',
							],
							'description' => esc_html__( '(px)', 'retirio' )
						]
					);

		        $element->end_controls_tab();

		        $element->start_controls_tab(
		            'tab_custom_button_hover',
		            [
		                'label' => esc_html__( 'Hover', 'retirio' ),
		            ]
		        );

				    $element->add_responsive_control(
						'button_before_width_hover',
						[
							'label' 		=> esc_html__( 'Width', 'retirio' ),
							'type' 			=> \Elementor\Controls_Manager::SLIDER,
							'size_units' 	=> ['%'],
							'default' => [
								'unit' => '%',
								'size' => 100,
							],
							'range' => [
								'%' => [
									'min' => 0,
									'max' => 100,
									'step' => 1,
								],
							],
							'selectors' => [
								'{{WRAPPER}} .elementor-button-wrapper .elementor-button:hover:before' => 'width: {{SIZE}}{{UNIT}};',
							],
							'description' => esc_html__( '(%)', 'retirio' )
						]
					);

					$element->add_responsive_control(
						'button_before_height_hover',
						[
							'label' 		=> esc_html__( 'Height', 'retirio' ),
							'type' 			=> \Elementor\Controls_Manager::SLIDER,
							'size_units' 	=> ['%'],
							'default' => [
								'unit' => '%',
								'size' => 100,
							],
							'range' => [
								'%' => [
									'min' => 0,
									'max' => 100,
									'step' => 1,
								],
							],
							'selectors' => [
								'{{WRAPPER}} .elementor-button-wrapper .elementor-button:hover:before' => 'height: {{SIZE}}{{UNIT}};',
							],
							'description' => esc_html__( '(%)', 'retirio' )
						]
					);

		        $element->end_controls_tab();

		    $element->end_controls_tabs();

		    $element->add_responsive_control(
				'button_width',
				[
					'label' 		=> esc_html__( 'Button Width', 'retirio' ),
					'type' 			=> \Elementor\Controls_Manager::SLIDER,
					'size_units' 	=> ['%','px'],
					'default' => [
						'unit' => '%',
					],
					'range' => [
						'%' => [
							'min' => 20,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .elementor-button-wrapper .elementor-button' => 'width: {{SIZE}}{{UNIT}};',
					],
					'separator' => 'before'
				]
			);

		$element->end_controls_section();
	}

	// Ova accordion custom 
    function retirio_accordion_custom( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_accordion',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Accordion', 'retirio' ),
			]
		);

		    $element->add_responsive_control(
				'accordion_content_heading',
				[
					'label' 		=> esc_html__( 'Content', 'retirio' ),
					'type' 			=> \Elementor\Controls_Manager::HEADING,
				]
			);

			$element->add_responsive_control(
				'accordion_content_margin',
				[
					'label' 		=> esc_html__( 'Margin', 'retirio' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$element->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'accordion_content_border',
					'label' => esc_html__( 'Border', 'retirio' ),
					'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-content',
				]
			);

			$element->add_control(
				'border_top_color_content',
				[
					'label' 	=> esc_html__( 'Border Top Color', 'retirio' ),
					'type' 		=> \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .elementor-accordion .elementor-tab-content' => 'border-top-color : {{VALUE}};',	
					],
					'separator' => 'before'
				]
			);

		$element->end_controls_section();
	}  
    

}

return new Retirio_Elementor();





