<?php
/**
 * @package    OVA Project by ovatheme
 * @author     Ovatheme
 * @copyright  Copyright (C) 2022 Ovatheme All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 */

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Ova_Elementor_Project_Filter extends Widget_Base {

	public function get_name() {
		return 'ova_elementor_project_filter';
	}

	public function get_title() {
		return esc_html__( 'Project Filter', 'ova-project' );
	}

	public function get_icon() {
		return 'eicon-gallery-justified';
	}

	public function get_categories() {
		return [ 'ovapro' ];
	}

	public function get_script_depends() {
  		return [ 'ova-elementor-project-filter' ];
	} 	


	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'ova-project' ),
			]
		);

			$this->add_control(
				'template',
				[
					'label'   => esc_html__( 'Template', 'ova-project' ),
					'type'    => Controls_Manager::SELECT,
					'default' => 'template1',
					'options' => [
						'template1' => esc_html__('Year', 'ova-project'),
						'template2' => esc_html__('Category', 'ova-project'),   
					]
				]
			);

			$this->add_control(
				'show_category',
				[
					'label' => esc_html__( 'Show Category', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'ova-project' ),
					'label_off' => esc_html__( 'Hide', 'ova-project' ),
					'return_value' => 'yes',
					'default' => 'yes',
				]
			);


			// Add Class control

			$this->add_control(
				'total_count',
				[
					'label'   => esc_html__( 'Total', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 6
				]
			);

			$this->add_control(
				'number_column',
				[
					'label' => esc_html__( 'Number Of Column', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'three_column',
					'options' => [
						'two_column'     => esc_html__( '2 Columns', 'ova-project' ),
						'three_column' 	 => esc_html__( '3 Columns', 'ova-project' ),
						'four_column'    => esc_html__( '4 Columns', 'ova-project' ),
					],
					'condition' => [
						'template' => 'template2',
					],

				]
			);

			$this->add_control(
				'orderby_post',
				[
					'label' => esc_html__( 'OrderBy Post', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'ID',
					'options' => [
						'ID'  => esc_html__( 'ID', 'ova-project' ),
						'title'  => esc_html__( 'Title', 'ova-project' ),
						'post_date'=> esc_html__( 'Post Date', 'ova-project' ),
					],
				]
			);

			$this->add_control(
				'order',
				[
					'label' => esc_html__( 'Order', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'ASC',
					'options' => [
						'ASC'  => esc_html__( 'Ascending', 'ova-project' ),
						'DESC'  => esc_html__( 'Descending', 'ova-project' ),
					],
				]
			);

			$this->add_control(
				'offset',
				[
					'label'   => esc_html__( 'Offset', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 0
				]
			);

			$this->add_control(
				'show_category_empty',
				[
					'label' => esc_html__( 'Category Empty', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'ova-project' ),
					'label_off' => esc_html__( 'Hide', 'ova-project' ),
					'return_value' => 'yes',
					'default' => 'yes',
				]
			);

			$this->add_control(
				'show_link_to_detail',
				[
					'label' => esc_html__( 'Show Link to Detail', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'ova-project' ),
					'label_off' => esc_html__( 'Hide', 'ova-project' ),
					'return_value' => 'yes',
					'default' => 'yes',
				]
			);

			$this->add_control(
				'show_mask',
				[
					'label' => esc_html__( 'Show Mask', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'ova-project' ),
					'label_off' => esc_html__( 'Hide', 'ova-project' ),
					'return_value' => 'yes',
					'default' => 'no',
				]
			);

			$this->add_control(
				'mask_bg_color',
				[
					'label' => esc_html__( 'Mask Background Color', 'retirio' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .item-project-5 .img-project a .mask' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'show_mask' => 'yes',
					],
				]
			);

			$this->add_responsive_control(
				'background_image_opacity',
				[
					'label' 		=> esc_html__( 'Opacity', 'retirio' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0.3,
							'max' => 1,
							'step' => 0.02,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .item-project-5 .img-project a .mask' => 'opacity: {{SIZE}};',
					],
					'condition' => [
						'show_mask' => 'yes',
					],
				]
			);

		$this->end_controls_section();

	}

	protected function render() {

		$settings = $this->get_settings();
	
		$template = apply_filters( 'el_ovapro_project_filter', 'elementor/project_filter.php' );

		ob_start();
		ovapro_get_template( $template, $settings );
		echo ob_get_clean();
		
	}
}

$widgets_manager->register( new Ova_Elementor_Project_Filter() );