<?php
/**
 * @package    OVA Project by ovatheme
 * @author     Ovatheme
 * @copyright  Copyright (C) 2022 Ovatheme All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 */

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Ova_Elementor_Project_Filter_2 extends Widget_Base {

	public function get_name() {
		return 'ova_elementor_project_filter_2';
	}

	public function get_title() {
		return esc_html__( 'Project Filter 2', 'ova-project' );
	}

	public function get_icon() {
		return 'eicon-gallery-justified';
	}

	public function get_categories() {
		return [ 'ovapro' ];
	}

	public function get_script_depends() {
  		return [ 'ova-elementor-project-filter-2' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'ova-project' ),
			]
		);

			$this->add_control(
				'show_category',
				[
					'label' => esc_html__( 'Show Category', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'ova-project' ),
					'label_off' => esc_html__( 'Hide', 'ova-project' ),
					'return_value' => 'yes',
					'default' => 'yes',
				]
			);


			// Add Class control
			$this->add_control(
				'total_count',
				[
					'label'   => esc_html__( 'Total', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 5
				]
			);

			$this->add_control(
				'orderby_post',
				[
					'label' => esc_html__( 'OrderBy Post', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'post_date',
					'options' => [
						'ID'  => esc_html__( 'ID', 'ova-project' ),
						'title'  => esc_html__( 'Title', 'ova-project' ),
						'post_date'=> esc_html__( 'Post Date', 'ova-project' ),
					],
				]
			);

			$this->add_control(
				'order',
				[
					'label' => esc_html__( 'Order', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'DESC',
					'options' => [
						'ASC'  => esc_html__( 'Ascending', 'ova-project' ),
						'DESC'  => esc_html__( 'Descending', 'ova-project' ),
					],
				]
			);

			$this->add_control(
				'offset',
				[
					'label'   => esc_html__( 'Offset', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 0
				]
			);

			$this->add_control(
				'category_empty',
				[
					'label' => esc_html__( 'Category Empty', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'ova-project' ),
					'label_off' => esc_html__( 'Hide', 'ova-project' ),
					'return_value' => 'yes',
					'default' => 'no',
				]
			);


			$this->add_control(
				'show_link_to_detail',
				[
					'label' => esc_html__( 'Show Link to Detail', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'ova-project' ),
					'label_off' => esc_html__( 'Hide', 'ova-project' ),
					'return_value' => 'yes',
					'default' => 'yes',
				]
			);

		$this->end_controls_section();

	}

	protected function render() {

		$settings = $this->get_settings();
		
		$template = apply_filters( 'el_ovapro_project_filter_2', 'elementor/project_filter_2.php' );

		ob_start();
		ovapro_get_template( $template, $settings );
		echo ob_get_clean();
		
	}
}

$widgets_manager->register( new Ova_Elementor_Project_Filter_2() );