<?php
/**
 * @package    OVA Project by ovatheme
 * @author     Ovatheme
 * @copyright  Copyright (C) 2022 Ovatheme All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 */

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Ova_Elementor_Project_Filter_Ajax extends Widget_Base {

	public function get_name() {
		return 'ova_elementor_project_filter_ajax';
	}

	public function get_title() {
		return esc_html__( 'Project Filter Ajax', 'ova-project' );
	}

	public function get_icon() {
		return 'eicon-gallery-justified';
	}

	public function get_categories() {
		return [ 'ovapro' ];
	}

	public function get_script_depends() {
		wp_enqueue_style( 'owl-carousel', OVAPRO_PLUGIN_URI.'assets/libs/carousel/owl.carousel.min.css' );
		wp_enqueue_script( 'owl-carousel', OVAPRO_PLUGIN_URI.'assets/libs/carousel/owl.carousel.min.js', array('jquery'), false, true );
  		
  		wp_enqueue_script('project-fancybox', OVAPRO_PLUGIN_URI.'assets/libs/fancybox/fancybox.min.js', array('jquery'),null,true);
		wp_enqueue_style('project-fancybox', OVAPRO_PLUGIN_URI.'assets/libs/fancybox/fancybox.css', array(), null);

  		return [ 'ova-elementor-project-filter-ajax' ];
	}

  	
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'ova-project' ),
			]
		);


			$this->add_control(
				'total_count',
				[
					'label'   => esc_html__( 'Total', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => -1
				]
			);

			$this->add_control(
				'offset',
				[
					'label'   => esc_html__( 'Offset', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 0
				]
			);

			$this->add_control(
				'orderby_post',
				[
					'label' => esc_html__( 'OrderBy Post', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'ID',
					'options' => [
						'ID'  => esc_html__( 'ID', 'ova-project' ),
						'title'  => esc_html__( 'Title', 'ova-project' ),
					],
				]
			);

			$this->add_control(
				'order',
				[
					'label' => esc_html__( 'Order', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'ASC',
					'options' => [
						'ASC'  => esc_html__( 'Ascending', 'ova-project' ),
						'DESC'  => esc_html__( 'Descending', 'ova-project' ),
					],
				]
			);

		$this->end_controls_section();

        /*****************************************************************
						START SECTION ADDITIONAL
		******************************************************************/

		$this->start_controls_section(
			'section_additional_options',
			[
				'label' => esc_html__( 'Additional Options Slider', 'ova-project' ),
			]
		);

			$this->add_control(
				'margin_items',
				[
					'label'   => esc_html__( 'Margin Right Items', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 30,
					'description' => esc_html__( 'Item space between', 'ova-project' ),
				]	
			);

			$this->add_control(
				'stagePadding',
				[
					'label'   => esc_html__( 'Stage Padding', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 0,
				]
				
			);

			$this->add_control(
				'item_number',
				[
					'label'       => esc_html__( 'Item Number', 'ova-project' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Number Item', 'ova-project' ),
					'default'     => 1,
				]
			);

			$this->add_control(
				'slides_to_scroll',
				[
					'label'       => esc_html__( 'Slides to Scroll', 'ova-project' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'ova-project' ),
					'default'     => 1,
				]
			);

			$this->add_control(
				'pause_on_hover',
				[
					'label'   => esc_html__( 'Pause on Hover', 'ova-project' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'ova-project' ),
						'no'  => esc_html__( 'No', 'ova-project' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'infinite',
				[
					'label'   => esc_html__( 'Infinite Loop', 'ova-project' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'false',
					'options' => [
						'yes' => esc_html__( 'Yes', 'ova-project' ),
						'no'  => esc_html__( 'No', 'ova-project' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay',
				[
					'label'   => esc_html__( 'Autoplay', 'ova-project' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'false',
					'options' => [
						'yes' => esc_html__( 'Yes', 'ova-project' ),
						'no'  => esc_html__( 'No', 'ova-project' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay_speed',
				[
					'label'     => esc_html__( 'Autoplay Speed', 'ova-project' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => 3000,
					'step'      => 500,
					'condition' => [
						'autoplay' => 'yes',
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'smartspeed',
				[
					'label'   => esc_html__( 'Smart Speed', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 1500,
				]
			);

			$this->add_control(
				'nav_control',
				[
					'label'   => esc_html__( 'Show Nav', 'ova-project' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'ova-project' ),
						'no'  => esc_html__( 'No', 'ova-project' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'dots_control',
				[
					'label'   => esc_html__( 'Show Dots on mobile', 'ova-project' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'ova-project' ),
						'no'  => esc_html__( 'No', 'ova-project' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'class_icon_next_control',
				[
					'label'   => esc_html__( 'Icon Next', 'ova-project' ),
					'type'    => Controls_Manager::ICONS,
					'default' => [
						'value' => 'ovaicon ovaicon-next',
						'library' => 'ovaicon'
					],
					'condition' => [
						'nav_control' => 'yes'
					]
				]
			);

			$this->add_control(
				'text_next_control',
				[
					'label' => esc_html__( 'Text Next', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__('Next', 'ova-project'),
					'condition' => [
						'nav_control' => 'yes'
					]
				]
			);

			$this->add_control(
				'class_icon_prev_control',
				[
					'label'   => esc_html__( 'Icon Prev', 'ova-project' ),
					'type'    => Controls_Manager::ICONS,
					'default' => [
						'value' => 'ovaicon ovaicon-back',
						'library' => 'ovaicon'
					],
					'condition' => [
						'nav_control' => 'yes'
					]
				]
			);

			$this->add_control(
				'text_previous_control',
				[
					'label' => esc_html__( 'Text Previous', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__('Previous', 'ova-project'),
					'condition' => [
						'nav_control' => 'yes'
					]
				]
			);


		$this->end_controls_section();

		/****************************  END SECTION ADDITIONAL *********************/


		/****************************  SECTION TAB STYLE CATEGORY *********************/
		$this->start_controls_section(
			'style_section_category',
			[
				'label' => esc_html__( 'Style Category', 'ova-project' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->start_controls_tabs(
			'style_category_tabs'
			);

				$this->start_controls_tab(
					'style_normal_category_tab',
					[
						'label' => esc_html__( 'Normal', 'ova-project' ),
					]
				);

					$this->add_control(
						'label_category_color',
						[
							'label' => esc_html__( 'Color', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider ul li' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Typography::get_type(),
						[
							'name' => 'category_label_typography',
							'selector' => '{{WRAPPER}} .ova-project-slider ul li ',
						]
					);


				
				$this->end_controls_tab();

				$this->start_controls_tab(
					'style_hover_category_tab',
					[
						'label' => esc_html__( 'Hover', 'ova-project' ),
					]
				);

					$this->add_control(
						'label_category_color_hover',
						[
							'label' => esc_html__( 'Color', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider ul li:hover .category' => 'color : {{VALUE}};',
								'{{WRAPPER}} .ova-project-slider ul li:hover .category-total' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Typography::get_type(),
						[
							'name' => 'category_label_typography_hover',
							'selector' => '{{WRAPPER}} .ova-project-slider ul li:hover .category',
						]
					);

				$this->end_controls_tab();

				$this->start_controls_tab(
					'style_active_category_tab',
					[
						'label' => esc_html__( 'Active', 'ova-project' ),
					]
				);

					$this->add_control(
						'label_category_color_active',
						[
							'label' => esc_html__( 'Color', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider ul li.active-category .category' => 'color : {{VALUE}};',
								'{{WRAPPER}} .ova-project-slider ul li.active-category .category-total' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Typography::get_type(),
						[
							'name' => 'category_label_typography_active',
							'selector' => '{{WRAPPER}} .ova-project-slider ul li.active-category .category',
						]
					);

				$this->end_controls_tab();

			$this->end_controls_tabs();

			$this->add_control(
			'total_tab',
				[
					'label' => esc_html__( 'Total Category', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

				$this->start_controls_tabs(
				'style_total_category_tabs'
				);

					$this->start_controls_tab(
						'style_total_category_tab',
						[
							'label' => esc_html__( 'Normal', 'ova-project' ),
						]
					);
						
						$this->add_group_control(
							\Elementor\Group_Control_Typography::get_type(),
							[
								'name' => 'category_total_label_typography',
								'selector' => '{{WRAPPER}} .ova-project-slider ul li .category-total',
							]
						);

						$this->add_control(
							'label_category_total_color',
							[
								'label' => esc_html__( 'Color', 'ova-project' ),
								'type' => Controls_Manager::COLOR,
								'selectors' => [
									'{{WRAPPER}} .ova-project-slider ul li .category-total' => 'color : {{VALUE}};',
								],
							]
						);

					$this->end_controls_tab();

					$this->start_controls_tab(
						'style_total_hover_category_tab',
						[
							'label' => esc_html__( 'Hover', 'ova-project' ),
						]
					);
						//code
						$this->add_group_control(
							\Elementor\Group_Control_Typography::get_type(),
							[
								'name' => 'category_total_label_typography_hover',
								'selector' => '{{WRAPPER}} .ova-project-slider ul li:hover .category-total',
							]
						);

						$this->add_control(
							'label_category_total_color_hover',
							[
								'label' => esc_html__( 'Color', 'ova-project' ),
								'type' => Controls_Manager::COLOR,
								'selectors' => [
									'{{WRAPPER}} .ova-project-slider ul li:hover .category-total' => 'color : {{VALUE}};',
								],
							]
						);
					$this->end_controls_tab();

					$this->start_controls_tab(
						'style_total_active_category_tab',
						[
							'label' => esc_html__( 'Active', 'ova-project' ),
						]
					);

						$this->add_group_control(
							\Elementor\Group_Control_Typography::get_type(),
							[
								'name' => 'category_total_label_typography_active',
								'selector' => '{{WRAPPER}} .ova-project-slider ul li.active-category .category-total',
							]
						);
						$this->add_control(
							'label_category_total_color_active',
							[
								'label' => esc_html__( 'Color', 'ova-project' ),
								'type' => Controls_Manager::COLOR,
								'selectors' => [
									'{{WRAPPER}} .ova-project-slider ul li.active-category .category-total' => 'color : {{VALUE}};',
								],
							]
						);
					$this->end_controls_tab();

				$this->end_controls_tabs();
				//end tab total category
			
			$this->add_control(
			'line_tab',
				[
					'label' => esc_html__( 'Line Tab', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

				// tab Line category
				$this->start_controls_tabs(
				'style_line_category_tabs'
				);
					
					$this->start_controls_tab(
						'style_line_tab_left',
						[
							'label' => esc_html__( 'Line Left', 'ova-project' ),
						]
					);
					// code
						$this->add_control(
							'line_left_width',
							[
								'label' => esc_html__( 'Width', 'ova-project' ),
								'type' => Controls_Manager::SLIDER,
								'size_units' => [ 'px' ],
								'range' => [
									'px' => [
										'min' => 1,
										'max' => 50,
										'step' => 1,
									]
								],
								
								'selectors' => [
									'{{WRAPPER}} .ova-project-slider ul li .line-1' => 'width: {{SIZE}}{{UNIT}};',
								],
							]
						);

						$this->add_control(
							'line_left_height',
							[
								'label' => esc_html__( 'Height', 'ova-project' ),
								'type' => Controls_Manager::SLIDER,
								'size_units' => [ 'px', '%' ],
								'range' => [
									'px' => [
										'min' => 1,
										'max' => 50,
										'step' => 1,
									],

								],
								
								'selectors' => [
									'{{WRAPPER}} .ova-project-slider ul li .line-1' => 'height: {{SIZE}}{{UNIT}};',
								],
							]
						);

						$this->add_control(
							'label_line_left_color',
							[
								'label' => esc_html__( 'Color', 'ova-project' ),
								'type' => Controls_Manager::COLOR,
								'selectors' => [
									'{{WRAPPER}} .ova-project-slider ul li .line-1' => 'background-color : {{VALUE}};',
								],
							]
						);
						$this->add_control(
							'label_line_left_color_active',
							[
								'label' => esc_html__( 'Color Active', 'ova-project' ),
								'type' => Controls_Manager::COLOR,
								'selectors' => [
									'{{WRAPPER}} .ova-project-slider ul li.active-category .line-1' => 'background-color : {{VALUE}};',
								],
							]
						);

					$this->end_controls_tab();

					$this->start_controls_tab(
						'style_line_bottom_category_tab',
						[
							'label' => esc_html__( 'Line Bottom', 'ova-project' ),
						]
					);
					// code
						$this->add_control(
							'line_bottom_width',
							[
								'label' => esc_html__( 'Width', 'ova-project' ),
								'type' => Controls_Manager::SLIDER,
								'size_units' => [ 'px','%' ],
								'range' => [
									'px' => [
										'min' => 1,
										'max' => 100,
										'step' => 1,
									]
								],
								
								'selectors' => [
									'{{WRAPPER}} .ova-project-slider ul li .line-2' => 'width: {{SIZE}}{{UNIT}};',
								],
							]
						);

						$this->add_control(
							'line_bottom_height',
							[
								'label' => esc_html__( 'Height', 'ova-project' ),
								'type' => Controls_Manager::SLIDER,
								'size_units' => [ 'px', '%' ],
								'range' => [
									'px' => [
										'min' => 1,
										'max' => 50,
										'step' => 1,
									],

								],
								
								'selectors' => [
									'{{WRAPPER}} .ova-project-slider ul li .line-2' => 'height: {{SIZE}}{{UNIT}};',
								],
							]
						);

						$this->add_control(
							'label_line_bottom_color',
							[
								'label' => esc_html__( 'Color', 'ova-project' ),
								'type' => Controls_Manager::COLOR,
								'selectors' => [
									'{{WRAPPER}} .ova-project-slider ul li .line-2' => 'background-color : {{VALUE}};',
								],
							]
						);
						
					$this->end_controls_tab();

				$this->end_controls_tabs();
			

		$this->end_controls_section();
		/****************************  END SECTION TAB STYLE CATEGORY *********************/


		/****************************  SECTION TAB STYLE SLIDER *********************/
		$this->start_controls_section(
			'style_section_slider',
			[
				'label' => esc_html__( 'Slider', 'ova-project' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
	            'owlstage_margin',
	            	[
	                'label'         => esc_html__( 'Margin Owl-stage', 'ova-project' ),
	                'type'          => Controls_Manager::DIMENSIONS,
	                'size_units'    => [ 'px', '%', 'em' ],
	                'selectors'     => [
	                    '{{WRAPPER}} .ova-project-slider .owl-carousel .owl-stage' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		                ],
	            ]
			);

			$this->add_control(
				'button_nav',
				[
					'label' => esc_html__( 'Button Nav', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			// tab slider normal
			$this->start_controls_tabs(
			'style_slider_button_tabs'
			);

				$this->start_controls_tab(
					'style_button_tab',
					[
						'label' => esc_html__( 'Normal', 'ova-project' ),
					]
				);

				$this->add_responsive_control(
					'nav_next_padding',
					[
						'label' => esc_html__( 'Padding Next', 'ova-project' ),
						'type' => Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors' => [
							'{{WRAPPER}} .ova-project-slider .owl-carousel .owl-nav button.owl-next' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}!important;',
						],
					]
				);

				$this->add_responsive_control(
					'nav_pre_padding',
					[
						'label' => esc_html__( 'Padding Prev', 'ova-project' ),
						'type' => Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors' => [
							'{{WRAPPER}} .ova-project-slider .owl-carousel .owl-nav button.owl-prev' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}!important;',
						],
					]
				);

					$this->add_control(
						'style_slider_button_tabs_color',
						[
							'label' => esc_html__( 'Color', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .owl-carousel .owl-nav button.owl-prev' => 'color : {{VALUE}};',
								'{{WRAPPER}} .ova-project-slider .owl-carousel .owl-nav button.owl-next' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'style_slider_button_tabs_bg_color',
						[
							'label' => esc_html__( 'Background', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .owl-carousel .owl-nav button.owl-prev' => 'background-color : {{VALUE}};',
								'{{WRAPPER}} .ova-project-slider .owl-carousel .owl-nav button.owl-next' => 'background-color : {{VALUE}};',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Typography::get_type(),
						[
							'name' => 'typography_button_nav',
							'selector' => '{{WRAPPER}} .ova-project-slider .owl-carousel .owl-nav button.owl-prev,.ova-project-slider .owl-carousel .owl-nav button.owl-next',
						]
					);
					
				$this->end_controls_tab();

				// hover button
				$this->start_controls_tab(
					'style_button_hover_tab',
					[
						'label' => esc_html__( 'Hover', 'ova-project' ),
					]
				);

					$this->add_control(
						'style_slider_button_tabs_color_hover',
						[
							'label' => esc_html__( 'Background', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .owl-carousel .owl-nav button:hover.owl-prev' => 'color : {{VALUE}};',
								'{{WRAPPER}} .ova-project-slider .owl-carousel .owl-nav button:hover.owl-next' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'style_slider_button_tabs_bg_color_hover',
						[
							'label' => esc_html__( 'Background', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .owl-carousel .owl-nav button:hover.owl-prev' => 'background-color : {{VALUE}};',
								'{{WRAPPER}} .ova-project-slider .owl-carousel .owl-nav button:hover.owl-next' => 'background-color : {{VALUE}};',
							],
						]
					);
				$this->end_controls_tab();

			$this->end_controls_tabs();

			// content title + category
			$this->add_control(
			'title_category_slider',
				[
					'label' => esc_html__( 'Info', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_responsive_control(
				'info_padding',
				[
					'label' => esc_html__( 'Padding', 'ova-project' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-project-slider .content-item .project-slider .info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Background::get_type(),
				[
					'name' => 'background_mask_info',
					'label' => esc_html__( 'Background', 'ova-project' ),
					'types' => [ 'classic', 'gradient', 'video' ],
					'selector' => '{{WRAPPER}} .ova-project-slider .content-item .project-slider .info .mask',
				]
			);

			// tab slider normal
			$this->start_controls_tabs(
			'style_slider_content_title'
			);

				$this->start_controls_tab(
					'style_content_tab',
					[
						'label' => esc_html__( 'Title', 'ova-project' ),
					]
				);

					$this->add_group_control(
						\Elementor\Group_Control_Typography::get_type(),
						[
							'name' => 'typography_content_title',
							'selector' => '{{WRAPPER}} .ova-project-slider .content-item .project-slider .info .name a',
						]
					);

					$this->add_control(
						'style_slider_tabs_content_title_color',
						[
							'label' => esc_html__( 'Color', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .content-item .project-slider .info .name a' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'style_slider_tabs_content_title_color_hover',
						[
							'label' => esc_html__( 'Color hover', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .content-item .project-slider .info .name a:hover' => 'color : {{VALUE}};',
							],
						]
					);
				
				$this->end_controls_tab();

				$this->start_controls_tab(
					'style_content_slider_category_tab',
					[
						'label' => esc_html__( 'Category', 'ova-project' ),
					]
				);

					$this->add_group_control(
						\Elementor\Group_Control_Typography::get_type(),
						[
							'name' => 'typography_content_category',
							'selector' => '{{WRAPPER}} .ova-project-slider .content-item .project-slider .info .project-category a,.ova-project-slider .content-item .project-slider .info .project-category', 
						]
					);

					$this->add_control(
						'style_slider_tabs_content_category_color',
						[
							'label' => esc_html__( 'Color', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .content-item .project-slider .info .project-category a' => 'color : {{VALUE}};',
								'{{WRAPPER}} .ova-project-slider .content-item .project-slider .info .project-category' => 'color : {{VALUE}};'
							],
						]
					);

					$this->add_control(
						'style_slider_tabs_content_category_color_hover',
						[
							'label' => esc_html__( 'Color hover', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .content-item .project-slider .info .project-category a:hover' => 'color : {{VALUE}};',
							],
						]
					);
				$this->end_controls_tab();

			$this->end_controls_tabs();

			// button gallery
			$this->add_control(
			'button_gallery_slider',
				[
					'label' => esc_html__( 'button gallery slider', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->start_controls_tabs(
			'style_slider_gallery_tabs'
			);

				$this->start_controls_tab(
					'style_gallery_button_tab',
					[
						'label' => esc_html__( 'Normal', 'ova-project' ),
					]
				);

					$this->add_responsive_control(
						'button_gallery_padding',
						[
							'label' => esc_html__( 'Padding', 'ova-project' ),
							'type' => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', 'em', '%' ],
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .content-item .project-slider .img-project .button-gallery' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
					);
					
					$this->add_responsive_control(
						'icon_button_gallery_padding',
						[
							'label' => esc_html__( 'Padding Icon', 'ova-project' ),
							'type' => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', 'em', '%' ],
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .content-item .project-slider .img-project .button-gallery i:before' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
					);

					$this->add_control(
						'icon_button_gallery_color',
						[
							'label' => esc_html__( 'Color Icon', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .content-item .project-slider .img-project .button-gallery i:before' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'icon_button_gallery_background',
						[
							'label' => esc_html__( 'Background Color Icon', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .content-item .project-slider .img-project .button-gallery i:before' => 'background-color : {{VALUE}};',
							],
						]
					);
					
				
				$this->end_controls_tab();

				// hvoer button
				$this->start_controls_tab(
					'style_button_gallery_hover_tab',
					[
						'label' => esc_html__( 'Hover', 'ova-project' ),
					]
				);

					$this->add_control(
						'icon_button_gallery_color_hover',
						[
							'label' => esc_html__( 'Color Icon', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .content-item .project-slider .img-project .button-gallery:hover i:before' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'icon_button_gallery_background_hover',
						[
							'label' => esc_html__( 'Background icon', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-slider .content-item .project-slider .img-project .button-gallery:hover i:before' => 'background-color : {{VALUE}};',
							],
						]
					);

				$this->end_controls_tab();

			$this->end_controls_tabs();



		$this->end_controls_section();
		/****************************  END SECTION TAB STYLE SLIDER *********************/


	}

	protected function render() {

		$settings = $this->get_settings();
	
		$template = apply_filters( 'el_ovapro_project_filter_ajax', 'elementor/project_filter_ajax.php' );

		ob_start();
		ovapro_get_template( $template, $settings );
		echo ob_get_clean();
		
	}
}

$widgets_manager->register( new Ova_Elementor_Project_Filter_Ajax() );