<?php

if ( !defined( 'ABSPATH' ) ) exit();

if ( !class_exists( 'Ova_Project_Customize' ) ) {

	class Ova_Project_Customize {

		public function __construct() {
			add_action( 'customize_register', array( $this, 'ova_project_customize_register' ) );
		}

		public function ova_project_customize_register( $wp_customize ) {

			$this->ova_project_init( $wp_customize );

			do_action( 'ova_project_customize_register', $wp_customize );
		}


		/* Project */
		public function ova_project_init( $wp_customize ){
			
			$wp_customize->add_panel( 'ova_project_section' , array(
				'title'      => esc_html__( 'Projects', 'ova-project' ),
				'priority'   => 5
			) );

				// Archive
				$wp_customize->add_section( 'ova_project_archive_section' , array(
				    'title'     => esc_html__( 'Archive', 'ova-project' ),
				    'priority'  => 1,
				    'panel' 	=> 'ova_project_section'
				) );
					
					// Post per page
					$wp_customize->add_setting( 'ova_project_total_record', array(
						  'type' 				=> 'theme_mod', // or 'option'
						  'capability' 			=> 'edit_theme_options',
						  'theme_supports' 		=> '', // Rarely needed.
						  'default' 			=> '6',
						  'transport' 			=> 'refresh', // or postMessage
						  'sanitize_callback' 	=> 'sanitize_text_field' // Get function name 
						  
					) );
					
					$wp_customize->add_control('ova_project_total_record', array(
						'label' 	=> esc_html__('Number of posts per page','ova-project'),
						'section' 	=> 'ova_project_archive_section',
						'settings' 	=> 'ova_project_total_record',
						'type' 		=> 'number'
					));
					
					$wp_customize->add_setting( 'project_template', array(
					  'type' => 'theme_mod', // or 'option'
					  'capability' => 'edit_theme_options',
					  'theme_supports' => '', // Rarely needed.
					  'default' => 'template_1',
					  'transport' => 'refresh', // or postMessage
					  'sanitize_callback' => 'sanitize_text_field' // Get function name 
					  
					) );
					$wp_customize->add_control('project_template', array(
						'label' 	=> esc_html__('Template','ova-project'),
						'section' 	=> 'ova_project_archive_section',
						'settings' 	=> 'project_template',
						'type' 		=>'select',
						'choices' 	=> array(
							'template_1'   	=> esc_html__( 'Template 1', 'ova-project' ),
							'template_2'   => esc_html__( 'Template 2', 'ova-project' ),
							'template_3'  	=> esc_html__( 'Template 3', 'ova-project' ),
							'template_4'  	=> esc_html__( 'Template 4', 'ova-project' ),
						)
					));
                    
                    // Column Layout
					$wp_customize->add_setting( 'ova_project_column_layout', array(
					  'type' => 'theme_mod', // or 'option'
					  'capability' => 'edit_theme_options',
					  'theme_supports' => '', // Rarely needed.
					  'default' => 'three_column',
					  'transport' => 'refresh', // or postMessage
					  'sanitize_callback' => 'sanitize_text_field' // Get function name 
					  
					) );

					$wp_customize->add_control('ova_project_column_layout', array(
						'label' => esc_html__('Column','ova-project'),
						'section' => 'ova_project_archive_section',
						'settings' => 'ova_project_column_layout',
						'type' =>'select',
						'choices' => array(
							'two_column'      => __( '2 column', 'ova-project' ),
							'three_column' => __( '3 column', 'ova-project' ),
							'four_column'      => __( '4 column', 'ova-project' ),
						)
					));

					// Header Archive Portfolio
					$wp_customize->add_setting( 'header_archive_project', array(
						'type' 				=> 'theme_mod', // or 'option'
						'capability' 		=> 'edit_theme_options',
						'theme_supports' 	=> '', // Rarely needed.
						'default' 			=> 'default',
						'transport' 		=> 'refresh', // or postMessage
						'sanitize_callback' => 'sanitize_text_field' // Get function name 
					) );

					$wp_customize->add_control('header_archive_project', array(
						'label' 	=> esc_html__('Header Archive','ova-project'),
						'section' 	=> 'ova_project_archive_section',
						'settings' 	=> 'header_archive_project',
						'type' 		=>'select',
						'choices' 	=> apply_filters( 'retirio_list_header', '' )
					));

					// Footer Archive Portfolio
					$wp_customize->add_setting( 'footer_archive_project', array(
						'type' 				=> 'theme_mod', // or 'option'
						'capability' 		=> 'edit_theme_options',
						'theme_supports' 	=> '', // Rarely needed.
						'default' 			=> 'default',
						'transport' 		=> 'refresh', // or postMessage
						'sanitize_callback' => 'sanitize_text_field' // Get function name 
					) );

					$wp_customize->add_control('footer_archive_project', array(
						'label' 	=> esc_html__('Footer Archive','ova-project'),
						'section' 	=> 'ova_project_archive_section',
						'settings' 	=> 'footer_archive_project',
						'type' 		=>'select',
						'choices' 	=> apply_filters('retirio_list_footer', '')
					));

				// Single
				$wp_customize->add_section( 'ova_project_single_section' , array(
				    'title'     => esc_html__( 'Single', 'ova-project' ),
				    'priority'  => 2,
				    'panel' 	=> 'ova_project_section',
				) );
                    
                    // Share social icon
				    $wp_customize->add_setting( 'project_single_show_share_social_icon', array(
					  'type' => 'theme_mod', // or 'option'
					  'capability' => 'edit_theme_options',
					  'theme_supports' => '', // Rarely needed.
					  'default' => 'yes',
					  'transport' => 'refresh', // or postMessage
					  'sanitize_callback' => 'sanitize_text_field' // Get function name 
					  
					) );
					
					$wp_customize->add_control('project_single_show_share_social_icon', array(
						'label' => esc_html__('Show Share Social Icon','retirio'),
						'section' => 'ova_project_single_section',
						'settings' => 'project_single_show_share_social_icon',
						'type' =>'select',
						'choices' => array(
							'yes' => esc_html__('Yes', 'retirio'),
							'no'		=> esc_html__('No', 'retirio'),
						)
					));

					// Header Single Project
					$wp_customize->add_setting( 'header_single_project', array(
						'type' 				=> 'theme_mod', // or 'option'
						'capability' 		=> 'edit_theme_options',
						'theme_supports' 	=> '', // Rarely needed.
						'default' 			=> 'default',
						'transport' 		=> 'refresh', // or postMessage
						'sanitize_callback' => 'sanitize_text_field' // Get function name 
					) );

					$wp_customize->add_control('header_single_project', array(
						'label' 	=> esc_html__('Header Single','ova-project'),
						'section' 	=> 'ova_project_single_section',
						'settings' 	=> 'header_single_project',
						'type' 		=>'select',
						'choices' 	=> apply_filters( 'retirio_list_header', '' )
					));

					// Footer Single Project
					$wp_customize->add_setting( 'footer_single_project', array(
						'type' 				=> 'theme_mod', // or 'option'
						'capability' 		=> 'edit_theme_options',
						'theme_supports' 	=> '', // Rarely needed.
						'default' 			=> 'default',
						'transport' 		=> 'refresh', // or postMessage
						'sanitize_callback' => 'sanitize_text_field' // Get function name 
					) );

					$wp_customize->add_control('footer_single_project', array(
						'label' 	=> esc_html__('Footer Single','ova-project'),
						'section' 	=> 'ova_project_single_section',
						'settings' 	=> 'footer_single_project',
						'type' 		=>'select',
						'choices' 	=> apply_filters('retirio_list_footer', '')
					));

					// Add customize
		}

	}

	new Ova_Project_Customize();
}