<?php 

if ( !defined( 'ABSPATH' ) ) exit();

if ( !class_exists( 'OVAPRO_custom_post_type' ) ) {

	class OVAPRO_custom_post_type{

		public function __construct(){
			add_action( 'init', array( $this, 'OVAPRO_register_post_type_project' ) );
			add_action( 'init', array( $this, 'OVAPRO_register_taxonomy_project' ) );
			add_action( 'init', array( $this, 'OVAPRO_register_taxonomy_year_project' ) );
		}

		function OVAPRO_register_post_type_project() {

			$labels = array(
				'name'                  => _x( 'Projects', 'Post Type General Name', 'ova-project' ),
				'singular_name'         => _x( 'Projects', 'Post Type Singular Name', 'ova-project' ),
				'menu_name'             => esc_html__( 'Projects', 'ova-project' ),
				'name_admin_bar'        => esc_html__( 'Project', 'ova-project' ),
				'archives'              => esc_html__( 'Item Archives', 'ova-project' ),
				'attributes'            => esc_html__( 'Item Attributes', 'ova-project' ),
				'parent_item_colon'     => esc_html__( 'Parent Item:', 'ova-project' ),
				'all_items'             => esc_html__( 'All Projects', 'ova-project' ),
				'add_new_item'          => esc_html__( 'Add New Project', 'ova-project' ),
				'add_new'               => esc_html__( 'Add New', 'ova-project' ),
				'new_item'              => esc_html__( 'New Item', 'ova-project' ),
				'edit_item'             => esc_html__( 'Edit', 'ova-project' ),
				'view_item'             => esc_html__( 'View Item', 'ova-project' ),
				'view_items'            => esc_html__( 'View Items', 'ova-project' ),
				'search_items'          => esc_html__( 'Search Item', 'ova-project' ),
				'not_found'             => esc_html__( 'Not found', 'ova-project' ),
				'not_found_in_trash'    => esc_html__( 'Not found in Trash', 'ova-project' ),
			);

			$args = array(
				'description'         => esc_html__( 'Post Type Description', 'ova-project' ),
				'labels'              => $labels,
				'supports'            => array( 'title', 'editor', 'thumbnail', 'comments' ),
				'hierarchical'        => false,
				'public'              => true,
				'show_ui'             => true,
				'menu_position'       => 5,
				'query_var'           => true,
				'has_archive'         => true,
				'exclude_from_search' => true,
				'publicly_queryable'  => true,
				'rewrite'             => array( 'slug' => _x( 'project', 'URL slug', 'ova-project' ) ),
				'capability_type'     => 'post',
				'show_in_rest'        => true,
				'menu_icon'           => 'dashicons-portfolio'
			);

			register_post_type( 'ova_projects', $args );
		}


		function OVAPRO_register_taxonomy_year_project(){
			
			$labels = array(
				'name'                       => _x( 'Year Project', 'Post Type General Name', 'ova-project' ),
				'singular_name'              => _x( 'Year Project', 'Post Type Singular Name', 'ova-project' ),
				'menu_name'                  => esc_html__( 'Year', 'ova-project' ),
				'all_items'                  => esc_html__( 'All Year Project', 'ova-project' ),
				'parent_item'                => esc_html__( 'Parent Item', 'ova-project' ),
				'parent_item_colon'          => esc_html__( 'Parent Item:', 'ova-project' ),
				'new_item_name'              => esc_html__( 'New Item Name', 'ova-project' ),
				'add_new_item'               => esc_html__( 'Add New Year Project', 'ova-project' ),
				'add_new'                    => esc_html__( 'Add New Year Project', 'ova-project' ),
				'edit_item'                  => esc_html__( 'Edit Year Project', 'ova-project' ),
				'view_item'                  => esc_html__( 'View Item', 'ova-project' ),
				'separate_items_with_commas' => esc_html__( 'Separate items with commas', 'ova-project' ),
				'add_or_remove_items'        => esc_html__( 'Add or remove items', 'ova-project' ),
				'choose_from_most_used'      => esc_html__( 'Choose from the most used', 'ova-project' ),
				'popular_items'              => esc_html__( 'Popular Items', 'ova-project' ),
				'search_items'               => esc_html__( 'Search Items', 'ova-project' ),
				'not_found'                  => esc_html__( 'Not Found', 'ova-project' ),
				'no_terms'                   => esc_html__( 'No items', 'ova-project' ),
				'items_list'                 => esc_html__( 'Items list', 'ova-project' ),
				'items_list_navigation'      => esc_html__( 'Items list navigation', 'ova-project' ),

			);

			$args = array(
				'labels'            	=> $labels,
				'hierarchical'      	=> true,
				'publicly_queryable' 	=> true,
				'public'            	=> true,
				'show_ui'           	=> true,
				'show_admin_column' 	=> true,
				'show_in_nav_menus' 	=> true,
				'show_tagcloud'     	=> false,
				'show_in_rest'        	=> true,
				'rewrite'            	=> array(
					'slug'       => _x( 'year_project', 'Category Project Slug', 'ova-project' ),
					'with_front' => false,
					'feeds'      => true,
				),
			);
			
			register_taxonomy( 'year_project', array( 'ova_projects' ), $args );
		
		}

		function OVAPRO_register_taxonomy_project(){
			
			$labels = array(
				'name'                       => _x( 'Category Project', 'Post Type General Name', 'ova-project' ),
				'singular_name'              => _x( 'Category Project', 'Post Type Singular Name', 'ova-project' ),
				'menu_name'                  => esc_html__( 'Categories', 'ova-project' ),
				'all_items'                  => esc_html__( 'All Category Project', 'ova-project' ),
				'parent_item'                => esc_html__( 'Parent Item', 'ova-project' ),
				'parent_item_colon'          => esc_html__( 'Parent Item:', 'ova-project' ),
				'new_item_name'              => esc_html__( 'New Item Name', 'ova-project' ),
				'add_new_item'               => esc_html__( 'Add New Category Project', 'ova-project' ),
				'add_new'                    => esc_html__( 'Add New Category Project', 'ova-project' ),
				'edit_item'                  => esc_html__( 'Edit Category Project', 'ova-project' ),
				'view_item'                  => esc_html__( 'View Item', 'ova-project' ),
				'separate_items_with_commas' => esc_html__( 'Separate items with commas', 'ova-project' ),
				'add_or_remove_items'        => esc_html__( 'Add or remove items', 'ova-project' ),
				'choose_from_most_used'      => esc_html__( 'Choose from the most used', 'ova-project' ),
				'popular_items'              => esc_html__( 'Popular Items', 'ova-project' ),
				'search_items'               => esc_html__( 'Search Items', 'ova-project' ),
				'not_found'                  => esc_html__( 'Not Found', 'ova-project' ),
				'no_terms'                   => esc_html__( 'No items', 'ova-project' ),
				'items_list'                 => esc_html__( 'Items list', 'ova-project' ),
				'items_list_navigation'      => esc_html__( 'Items list navigation', 'ova-project' ),

			);

			$args = array(
				'labels'            	=> $labels,
				'hierarchical'      	=> true,
				'publicly_queryable' 	=> true,
				'public'            	=> true,
				'show_ui'           	=> true,
				'show_admin_column' 	=> true,
				'show_in_nav_menus' 	=> true,
				'show_tagcloud'     	=> false,
				'show_in_rest'        	=> true,
				'rewrite'            	=> array(
					'slug'       => _x( 'category_project', 'Category Project Slug', 'ova-project' ),
					'with_front' => false,
					'feeds'      => true,
				),
			);
			
			register_taxonomy( 'category_project', array( 'ova_projects' ), $args );
		
		}

	}
	new OVAPRO_custom_post_type();
	
}